@@ -249,7 +249,10 @@ void ShortcutDelegate::setModelData(QWidget *editor, QAbstractItemModel *model,
 				if (UtilsUi::txsConfirmWarning(QString(ConfigDialog::tr("The shortcut <%1> is already assigned to the command:")).arg(value) + "\n" + duplicate + "\n\n" + ConfigDialog::tr("Do you wish to remove the old assignment and bind the shortcut to the new command?"))) {
 					//model->setData(mil[0],"",Qt::DisplayRole);
 					foreach (QTreeWidgetItem *twi, li) {
-						if (twi && twi->text(2) == value) twi->setText(2, "");
+						if (twi) {
+							if (twi->text(2) == value) twi->setText(2, "");
+                            if (twi->text(3) == value) twi->setText(3, "");
+						}
 					}
 				} else {
 					return;
@@ -476,7 +479,9 @@ ConfigDialog::ConfigDialog(QWidget *parent): QDialog(parent,Qt::Dialog|Qt::Windo
 #endif
 
 
-    ui.labelGetDic->setText(tr("Download additional dictionaries from %1 or %2").arg("<a href=\"http://extensions.openoffice.org/de/search?f[0]=field_project_tags%3A157\">OpenOffice</a>","<a href=\"https://extensions.libreoffice.org/extensions?getCategories=Dictionary&getCompatibility=any\">LibreOffice</a>"));
+    ui.labelGetDic->setText(tr("Download additional dictionaries from %1 or %2")
+            .arg("<a href=\"https://extensions.openoffice.org/de/search?f[0]=field_project_tags%3A157\">OpenOffice</a>",
+                 "<a href=\"https://extensions.libreoffice.org/?Tag%5B0%5D=50&q=&Tags%5B%5D=50\">LibreOffice</a>"));
 	ui.labelGetDic->setOpenExternalLinks(true);
 	//pagequick
 	connect(ui.pushButtonGrammarWordlists, SIGNAL(clicked()), this, SLOT(browseGrammarWordListsDir()));
@@ -502,6 +507,8 @@ ConfigDialog::ConfigDialog(QWidget *parent): QDialog(parent,Qt::Dialog|Qt::Windo
 
 	connect(ui.spinBoxSize, SIGNAL(valueChanged(int)), fmConfig, SLOT(setBasePointSize(int)));
 
+    connect(ui.leCompletionFilter,&QLineEdit::textChanged,this,&ConfigDialog::filterCompletionList);
+
 	//fmConfig->setMaximumSize(490,300);
 	//fmConfig->setSizePolicy(QSizePolicy::Ignored,QSizePolicy::Ignored);
 	QBoxLayout *layout = new QBoxLayout(QBoxLayout::TopToBottom, ui.formatConfigBox);
@@ -545,6 +552,8 @@ ConfigDialog::ConfigDialog(QWidget *parent): QDialog(parent,Qt::Dialog|Qt::Windo
 		CONTENTS_DISABLED
 #endif
 	);
+    // tweak all comboboxes in adv. editor pane to not change on scroll wheel as it messes with scrolling through the pane (#2977)
+    tweakFocusSettings(ui.scrollAreaWidgetContents_2->children());
 
 	Q_ASSERT(ui.pagesWidget->count() == ui.contentsWidget->count());
 
@@ -590,18 +599,25 @@ ConfigDialog::ConfigDialog(QWidget *parent): QDialog(parent,Qt::Dialog|Qt::Windo
 	connect(ui.tbRevertIcon, SIGNAL(clicked()), this, SLOT(revertClicked()));
 	connect(ui.tbRevertCentralIcon, SIGNAL(clicked()), this, SLOT(revertClicked()));
 	connect(ui.tbRevertSymbol, SIGNAL(clicked()), this, SLOT(revertClicked()));
-    connect(ui.tbRevertPDF, SIGNAL(clicked()), this, SLOT(revertClicked()));
+    connect(ui.tbRevertPDF, SIGNAL(clicked()), this, SLOT(revertClicked()));	
+}
 
-	// limit dialog size
-	QRect screen = QGuiApplication::primaryScreen()->geometry();
+
+void ConfigDialog::showAndLimitSize() {
+	show();
+	QRect screen = QGuiApplication::primaryScreen()->availableGeometry();
 	if (!screen.isEmpty()) {
-		int nwidth = width(), nheight = height();
-		if (nwidth > screen.width()) nwidth = screen.width();
-		if (nheight > screen.height()) nheight = screen.height();
+		int nwidth = width(), nheight = height(),
+			heightDiff = frameGeometry().height() - geometry().height(),
+			maxHeight = screen.height() - heightDiff, maxWidth = screen.width();
+
+		if (nwidth > maxWidth) nwidth = maxWidth;
+		if (nheight > maxHeight) nheight = maxHeight;
 		if (nwidth == width() && nheight == height()) return;
+
 		resize(nwidth, nheight);
 		move(frameGeometry().right() > screen.right() ? screen.left() : x(),
-		     frameGeometry().bottom() > screen.bottom() ? screen.left() : y());
+		   frameGeometry().bottom() > screen.bottom() ? screen.top() : y());	
 	}
 }
 
@@ -642,7 +658,7 @@ void ConfigDialog::revertClicked()
 	QToolButton *bt = qobject_cast<QToolButton *>(sender());
 	if (bt) {
 		if (bt->objectName() == "tbRevertIcon") {
-			ui.horizontalSliderIcon->setValue(22);
+			ui.horizontalSliderIcon->setValue(24);
 		}
 		if (bt->objectName() == "tbRevertCentralIcon") {
 			ui.horizontalSliderCentraIcon->setValue(16);
@@ -837,7 +853,32 @@ void ConfigDialog::hideShowAdvancedOptions(QWidget *w, bool on)
 			}
 		}
 		hideShowAdvancedOptions(w, on);
-	}
+    }
+}
+/*!
+ * \brief change focus and eventfilter to avoid accidental scrollen
+ * See #2977
+ * \param objList
+ */
+void ConfigDialog::tweakFocusSettings(QObjectList objList)
+{
+    for(auto *elem:objList){
+        QComboBox *cb=qobject_cast<QComboBox *>(elem);
+        if(cb){
+            cb->setFocusPolicy(Qt::StrongFocus);
+            cb->installEventFilter(this);
+        }
+        QSpinBox *sb=qobject_cast<QSpinBox *>(elem);
+        if(sb){
+            sb->setFocusPolicy(Qt::StrongFocus);
+            sb->installEventFilter(this);
+        }
+        auto *gb=qobject_cast<QGroupBox *>(elem);
+        if(gb){
+            // look into sub-boxes
+            tweakFocusSettings(gb->children());
+        }
+    }
 }
 
 void ConfigDialog::advancedOptionsToggled(bool on)
@@ -864,7 +905,7 @@ void ConfigDialog::advancedOptionsToggled(bool on)
 
 void ConfigDialog::advancedOptionsClicked(bool on)
 {
-	if (on) {
+	if (on & !riddled) {
 		if (!askRiddle()) ui.checkBoxShowAdvancedOptions->setChecked(false);
 		else riddled = true;
 	}
@@ -1159,7 +1200,19 @@ void ConfigDialog::updateCheckNow()
 
 void ConfigDialog::refreshLastUpdateTime()
 {
-	ui.labelUpdateCheckDate->setText(UpdateChecker::lastCheckAsString());
+    ui.labelUpdateCheckDate->setText(UpdateChecker::lastCheckAsString());
+}
+
+void ConfigDialog::filterCompletionList(const QString &text)
+{
+    for(int i=0;i<ui.completeListWidget->count();++i){
+        QListWidgetItem *item=ui.completeListWidget->item(i);
+        bool visible=item->text().contains(text, Qt::CaseInsensitive);
+        if(text.isEmpty()){
+            visible=true;
+        }
+        item->setHidden(!visible);
+    }
 }
 
 void ConfigDialog::populateComboBoxFont(bool onlyMonospaced)
@@ -1178,7 +1231,27 @@ void ConfigDialog::populateComboBoxFont(bool onlyMonospaced)
 	}
 	// restore font setting if possible
 	int idx = ui.comboBoxFont->findText(currentFont);
-	if (idx >= 0) ui.comboBoxFont->setCurrentIndex(idx);
+    if (idx >= 0) ui.comboBoxFont->setCurrentIndex(idx);
+}
+/*!
+ * \brief eventFilter for combobbox
+ * This filters wheel eents on unfocused combobox to avoid unwanted change on scrolling
+ * See #2977
+ * \param obj
+ * \param event
+ * \return
+ */
+bool ConfigDialog::eventFilter(QObject *obj, QEvent *event)
+{
+    if ( event->type() == QEvent::Wheel) {
+        auto *wdg=qobject_cast<QWidget*>( obj );
+        if( wdg && !wdg->hasFocus() )
+        {
+            event->ignore();
+            return true;
+        }
+    }
+    return QObject::eventFilter( obj, event );
 }
 
 #ifdef INTERNAL_TERMINAL
@@ -1233,4 +1306,3 @@ bool ConfigDialog::askRiddle()
 	return false;
 	*/
 }
-
