@@ -102,7 +102,8 @@ public:
 	QList<QMenu *> standardToolbarMenus;
 
 	void setBuildManger(BuildManager *buildManager) { mBuildManager = buildManager; }
-
+	void showAndLimitSize();
+	
 	bool riddled;
 public slots:
 	void changePage(QListWidgetItem *current, QListWidgetItem *previous);
@@ -139,6 +140,8 @@ private slots:
 	void updateCheckNow();
 	void refreshLastUpdateTime();
 
+    void filterCompletionList(const QString &text);
+
 	void revertClicked();
 
 	void populateComboBoxFont(bool onlyMonospaced);
@@ -147,13 +150,15 @@ private:
 	void populateTerminalColorSchemes();
 	void populateTerminalComboBoxFont(bool onlyMonospaced);
 #endif
-
+protected:
+    bool eventFilter(QObject *obj,QEvent *event);
 private:
 	enum ContentsType {CONTENTS_BASIC, CONTENTS_ADVANCED, CONTENTS_DISABLED};
 
 	QListWidgetItem *createIcon(const QString &caption, const QIcon &icon, ContentsType contentsType = CONTENTS_BASIC);
 	bool askRiddle();
 	void hideShowAdvancedOptions(QWidget *w, bool on);
+    void tweakFocusSettings(QObjectList objList);
 	static bool metaFilterRecurseWidget(const QString &filter, QWidget *widget);
 	static bool metaFilterRecurseLayout(const QString &filter, QLayout *layout);
 	static int lastUsedPage;
