@@ -83,6 +83,7 @@ public:
 
 
 	//appearance
+    bool systemUsesDarkMode(const QPalette &pal=QApplication::palette());
 	QPalette systemPalette;
 	QString interfaceStyle;
 	QString interfaceFontFamily;
@@ -121,6 +122,7 @@ public:
 	QTranslator *basicTranslator;
 
 	//editor
+	bool onlyMonospacedFonts;
 	LatexEditorViewConfig *const editorConfig;
 	//completion
 	LatexCompleterConfig *const completerConfig;
@@ -186,6 +188,7 @@ public:
 	bool parseBibTeX, parseMaster;
 	QString logFileEncoding, bibFileEncoding;
 	bool autoLoadChildren;
+    bool cacheDocuments;
 
     // insert cite command, when no context available
     QString citeCommand;
@@ -348,6 +351,7 @@ private:
 	void createCommandList(QGroupBox *box, const QStringList &order, bool user, bool meta);
 	void setFirstRowMoveUpEnable(bool enable);
 	void setLastRowMoveDownEnable(bool enable);
+    bool eventFilter(QObject *obj,QEvent *event);
 private slots:
 	void browseCommand();
 	void undoCommand();
@@ -371,4 +375,5 @@ private slots:
 private:
 	void updateManagedOptionObjects(ManagedProperty *property);
 };
+Q_DECLARE_METATYPE(ConfigManager::PreviewMode);
 #endif
