@@ -1,10 +1,12 @@
 #include "grammarcheck.h"
 #include "smallUsefulFunctions.h"
 #include "latexparser/latexreader.h"
+#include "latexparser/latex2text.h"
 #include "QThread"
 #include <QJsonDocument>
 #include <QJsonArray>
 
+
 GrammarError::GrammarError(): offset(0), length(0), error(GET_UNKNOWN) {}
 GrammarError::GrammarError(int offset, int length, const GrammarErrorType &error, const QString &message): offset(offset), length(length), error(error), message(message) {}
 GrammarError::GrammarError(int offset, int length, const GrammarErrorType &error, const QString &message, const QStringList &corrections): offset(offset), length(length), error(error), message(message), corrections(corrections) {}
@@ -13,7 +15,7 @@ GrammarError::GrammarError(int offset, int length, const GrammarError &other): o
 GrammarCheck::GrammarCheck(QObject *parent) :
     QObject(parent), ltstatus(LTS_Unknown), backend(nullptr), ticket(0), pendingProcessing(false), shuttingDown(false)
 {
-	latexParser = new LatexParser();
+    latexParser = QSharedPointer<LatexParser>::create();
 }
 /*!
  * \brief GrammarCheck::~GrammarCheck
@@ -21,7 +23,6 @@ GrammarCheck::GrammarCheck(QObject *parent) :
  */
 GrammarCheck::~GrammarCheck()
 {
-	delete latexParser;
     delete backend;
 }
 /*!
@@ -50,14 +51,57 @@ void GrammarCheck::init(const LatexParser &lp, const GrammarCheckerConfig &confi
 
 	// this is a heuristic, some LanguageTool languages have the format de-DE, others just it (instead of it-IT)
 	// this list contains all two-character languages that do not have a four-character equivalent.
-	languageMapping.insert("ca-CA", "ca");
-	languageMapping.insert("en-EN", "en");
-	languageMapping.insert("es-ES", "es");
-	languageMapping.insert("fa-FA", "fa");
-	languageMapping.insert("fr-FR", "fr");
-	languageMapping.insert("it-IT", "it");
-	languageMapping.insert("nl-NL", "nl");
-	languageMapping.insert("sv-SV", "sv");
+    languageMapping.insert("ast-ES","ast-ES");
+    languageMapping.insert("be-BY","be-BY");
+    languageMapping.insert("br-FR","br-FR");
+    languageMapping.insert("ca-CA", "ca");
+    languageMapping.insert("ca-ES","ca-ES");
+    languageMapping.insert("ca-ES-valencia","ca-ES-valencia");
+    languageMapping.insert("da-DK","da-DK");
+    languageMapping.insert("de-AT","de-AT");
+    languageMapping.insert("de-CH","de-CH");
+    languageMapping.insert("de-DE","de-DE");
+    languageMapping.insert("de-DE-x-simple-language-DE","de-DE-x-simple-language-DE");
+    languageMapping.insert("de-LU","de-LU");
+    languageMapping.insert("el-GR","el-GR");
+    languageMapping.insert("en-AU","en-AU");
+    languageMapping.insert("en-CA","en-CA");
+    languageMapping.insert("en-EN", "en");
+    languageMapping.insert("en-GB","en-GB");
+    languageMapping.insert("en-NZ","en-NZ");
+    languageMapping.insert("en-US","en-US");
+    languageMapping.insert("en-ZA","en-ZA");
+    languageMapping.insert("es-AR","es-AR");
+    //languageMapping.insert("es-ES", "es");
+    languageMapping.insert("es-ES","es-ES");
+    languageMapping.insert("fa-FA", "fa");
+    languageMapping.insert("fa-IR","fa-IR");
+    //languageMapping.insert("fr-FR", "fr");
+    languageMapping.insert("fr-FR","fr-FR");
+    languageMapping.insert("ga-IE","ga-IE");
+    languageMapping.insert("gl-ES","gl-ES");
+    //languageMapping.insert("it-IT", "it");
+    languageMapping.insert("it-IT","it-IT");
+    languageMapping.insert("ja-JP","ja-JP");
+    languageMapping.insert("km-KH","km-KH");
+    languageMapping.insert("nl-BE","nl-BE");
+    //languageMapping.insert("nl-NL", "nl");
+    languageMapping.insert("nl-NL","nl-NL");
+    languageMapping.insert("pl-PL","pl-PL");
+    languageMapping.insert("pt-AO","pt-AO");
+    languageMapping.insert("pt-BR","pt-BR");
+    languageMapping.insert("pt-MZ","pt-MZ");
+    languageMapping.insert("pt-PT","pt-PT");
+    languageMapping.insert("ro-RO","ro-RO");
+    languageMapping.insert("ru-RU","ru-RU");
+    languageMapping.insert("sk-SK","sk-SK");
+    languageMapping.insert("sl-SI","sl-SI");
+    languageMapping.insert("sv-SE","sv-SE");
+    languageMapping.insert("sv-SV", "sv");
+    languageMapping.insert("ta-IN","ta-IN");
+    languageMapping.insert("tl-PH","tl-PH");
+    languageMapping.insert("uk-UA","uk-UA");
+    languageMapping.insert("zh-CN","zh-CN");
 }
 
 QString GrammarCheck::serverUrl() {
@@ -88,11 +132,6 @@ QSet<QString> readWordList(const QString &file)
 	return res;
 }
 
-struct TokenizedBlock {
-	QStringList words;
-	QList<int> indices, endindices, lines;
-	//int firstLineNr;
-};
 
 struct CheckRequest {
 	bool pending;
@@ -154,37 +193,6 @@ void GrammarCheck::processLoop()
 	pendingProcessing = false;
 }
 
-const QString uselessPunctation = "!:?,.;-"; //useful: \"(
-const QString punctuationNotPreceededBySpace = "!:?,.;)\u00A0";  // \u00A0 is non-breaking space: assuming it is not surrounded by natural space (wouldn't make sense)
-const QString punctuationNotFollowedBySpace = "(\"\u00A0";
-
-
-/* Determine if words[i] should be preceeded by a space in the context of words.
- * If not continue.
- * If i > words.length() break;
- * This does always increase i by one. (Note: the checks below are written based on i++)
- * This is used in loops for selectively joining words with spaces. */
-
-
-#define PRECEED_WITH_SPACES(i,words)                                      \
-                                                                        \
-    (i)++;                                                              \
-                                                                        \
-    if((i) >= words.length())                                           \
-        break;                                                          \
-                                                                        \
-    if(words[i].length() == 1                                           \
-        && punctuationNotPreceededBySpace.contains(words[i][0]))        \
-            continue;                                                   \
-                                                                        \
-    if(words[(i) - 1].length() == 1                                     \
-        && punctuationNotFollowedBySpace.contains(words[(i) - 1][0]))   \
-            continue;                                                   \
-                                                                        \
-    if(words[(i) - 1].length() == 2 && words[(i) - 1][1] == '.'         \
-        && words[i].length() == 2 && words[i][1] == '.')                \
-            continue;
-
 
 
 void GrammarCheck::process(int reqId)
@@ -215,115 +223,7 @@ void GrammarCheck::process(int reqId)
 		}
 	}
 
-	//gather words
-	int nonTextIndex = 0;
-	QList<TokenizedBlock> blocks;
-	blocks << TokenizedBlock();
-	//blocks.last().firstLineNr = cr.firstLineNr;
-	int floatingBlocks = 0;
-	int firstLineNr = cr.firstLineNr;
-	for (int l = 0; l < cr.inlines.size(); l++, firstLineNr++) {
-		TokenizedBlock &tb = blocks.last();
-		LatexReader lr(*latexParser, cr.inlines[l].text);
-		int type;
-		while ((type = lr.nextWord(false))) {
-			if (type == LatexReader::NW_ENVIRONMENT) {
-				if (lr.word == "figure") { //config.floatingEnvs.contains(lr.word)) {
-					if (lr.lastCommand == "\\begin") {
-						floatingBlocks ++;
-					} else if (lr.lastCommand == "\\end") {
-						floatingBlocks --;
-					}
-				}
-				continue;
-			}
-
-			if (type == LatexReader::NW_COMMENT) break;
-			if (type != LatexReader::NW_TEXT && type != LatexReader::NW_PUNCTATION) {
-				//reference, label, citation
-				tb.words << QString("keyxyz%1").arg(nonTextIndex++);
-				tb.indices << lr.wordStartIndex;
-				tb.endindices << lr.index;
-				tb.lines << l;
-				continue;
-			}
-
-			if (latexParser->structureCommandLevel(lr.lastCommand) >= 0) {
-				//don't check captions
-				QStringList temp;
-				QList<int> starts;
-				LatexParser::resolveCommandOptions(lr.line, lr.wordStartIndex - 1, temp, &starts);
-				for (int j = 0; j < starts.count() && j < 2; j++) {
-					lr.index = starts.at(j) + temp.at(j).length() - 1;
-					if (temp.at(j).startsWith("{")) break;
-				}
-				tb.words << ".";
-				tb.indices << lr.wordStartIndex;
-				tb.endindices << 1;
-				tb.lines << l;
-				continue;
-			}
-
-
-			if (type == LatexReader::NW_TEXT) tb.words << lr.word;
-			else if (type == LatexReader::NW_PUNCTATION) {
-				if ((lr.word == "-") && !tb.words.isEmpty()) {
-					//- can either mean a word-separator or a sentence -- separator
-					// => if no space, join the words at both sides of the - (this could be easier handled in nextToken, but spell checking usually doesn't support - within words)
-					if (lr.wordStartIndex == tb.endindices.last()) {
-                        tb.words.last() += lr.word;
-						tb.endindices.last()++;
-
-						int tempIndex = lr.index;
-						int type = lr.nextWord(false);
-						if (type == LatexReader::NW_COMMENT) break;
-						if (tempIndex != lr.wordStartIndex) {
-							lr.index = tempIndex;
-							continue;
-						}
-						tb.words.last() += lr.word;
-						tb.endindices.last() = lr.index;
-						continue;
-					}
-				} else if (lr.word == "\"") {
-					lr.word = "'";  // replace " by ' because " is encoded as &quot; and screws up the (old) LT position calculation
-				} else if (lr.word == "~") {
-					lr.word =  "\u00A0";  // rewrite LaTeX non-breaking space to unicode non-braking space
-				} else if (punctuationNotPreceededBySpace.contains(lr.word) && !tb.words.isEmpty() && tb.words.last() == "\u00A0") {
-					// rewrite non-breaking space followed by punctuation to punctuation only. e.g. "figure~\ref{abc}." -> "figure."
-					// \ref{} is dropped by the reader and an erronous would leave "figure\u00A0."
-					// As a heuristic no space before punctuation takes precedence over non-breaking space.
-					// This is the best we can do for now. A complete handling of all cases is only possible with a full tokenization.
-					tb.words.last() = lr.word;
-					tb.endindices.last() = lr.index;
-					continue;
-				}
-				tb.words << lr.word;
-			}
-
-			tb.indices << lr.wordStartIndex;
-			tb.endindices << lr.index;
-			tb.lines << l;
-
-		}
-
-
-		while (floatingBlocks > blocks.size() - 1) blocks << TokenizedBlock();
-		while (floatingBlocks >= 0 && floatingBlocks < blocks.size() - 1)
-			cr.blocks << blocks.takeLast();
-	}
-	while (blocks.size()) cr.blocks << blocks.takeLast();
-
-
-	for (int b = 0; b < cr.blocks.size(); b++) {
-		TokenizedBlock &tb = cr.blocks[b];
-		while (!tb.words.isEmpty() && tb.words.first().length() == 1 && uselessPunctation.contains(tb.words.first()[0])) {
-			tb.words.removeFirst();
-			tb.indices.removeFirst();
-			tb.endindices.removeFirst();
-			tb.lines.removeFirst();
-		}
-	}
+    cr.blocks = tokenizeWords(latexParser.data(), cr.inlines);
 
     LTStatus newstatus = backend->isWorking() ? LTS_Working : LTS_Error;
 	if (newstatus != ltstatus) {
@@ -332,23 +232,14 @@ void GrammarCheck::process(int reqId)
 	}
 
 	QList<TokenizedBlock> crBlocks = cr.blocks; //cr itself might become invalid during the following loop
-    uint crTicket = cr.ticket;
+	uint crTicket = cr.ticket;
 	QString crLanguage = cr.language;
 
 	for (int b = 0; b < crBlocks.size(); b++) {
 		const TokenizedBlock &tb = crBlocks.at(b);
-        if (tb.words.isEmpty() || !backend->isAvailable() ) backendChecked(crTicket, b, QList<GrammarError>(), true);
+		if (tb.words.isEmpty() || !backend->isAvailable() ) backendChecked(crTicket, b, QList<GrammarError>(), true);
 		else  {
-			const QStringList &words = tb.words;
-            QString joined;
-			int expectedLength = 0;
-			foreach (const QString & s, words) expectedLength += s.length();
-            joined.reserve(expectedLength + words.length());
-            for (int i = 0;;) {
-                joined += words[i];
-                PRECEED_WITH_SPACES(i, words)
-                joined += " ";
-			}
+			QString joined = tb.toString();
 			backend->check(crTicket, b, crLanguage, joined);
 		}
 	}
@@ -461,35 +352,12 @@ void GrammarCheck::backendChecked(uint crticket, int subticket, const QList<Gram
 
 
 	//map indices to latex lines and indices
-	int curWord = 0, curOffset = 0;
-	int err = 0;
-	while (err < backendErrors.size()) {
-		if (backendErrors[err].offset >= curOffset + words[curWord].length()) {
-			curOffset += words[curWord].length();
-            PRECEED_WITH_SPACES(curWord, words)
-			curOffset++; //space
-		} else { //if (backendErrors[err].offset >= curOffset) {
-			int trueIndex = tb.indices[curWord] + qMax(0, backendErrors[err].offset - curOffset);
-			int trueLength = -1;
-			int offsetEnd = backendErrors[err].offset + backendErrors[err].length;
-			int tempOffset = curOffset;
-			for (int w = curWord; ; ) {
-				tempOffset += words[w].length();
-				if (tempOffset >=  offsetEnd) {
-					if (tb.lines[curWord] == tb.lines[w]) {
-						int trueOffsetEnd = tb.endindices[w] - qMax(0, tempOffset - offsetEnd);
-						trueLength = trueOffsetEnd - trueIndex;
-					}
-					break;
-				}
-                PRECEED_WITH_SPACES(w, words)
-				tempOffset++; //space
-			}
-			if (trueLength == -1)
-				trueLength = cr.inlines[tb.lines[curWord]].text.length() - trueIndex;
-			cr.errors[tb.lines[curWord]] << GrammarError(trueIndex, trueLength, backendErrors[err]);
-			err++;
-		}
+	TokenizedBlock::StringOffsetIterator tbit(tb, cr.inlines);
+	for (int err=0;err < backendErrors.size(); err++) {
+		int lineIndex, trueOffset, trueLength;
+		if (!tbit.map(backendErrors[err].offset, backendErrors[err].length, &lineIndex, &trueOffset, &trueLength))
+			break;
+		cr.errors[lineIndex] << GrammarError(trueOffset, trueLength, backendErrors[err]);
 	}
 
 	if (cr.handledBlocks == cr.blocks.size()) {
@@ -519,7 +387,17 @@ void GrammarCheck::updateLTStatus(){
 QString GrammarCheck::languageFromHunspellToLanguageTool(QString language)
 {
 	language.replace('_', '-');
-	return languageMapping.value(language, language);
+    QString result=language;
+    if(languageMapping.contains(language)){
+        result=languageMapping.value(language, language);
+    }else{
+        // just deliver the first part of the language code if no mapping is known
+        int i=language.indexOf('-');
+        if(i>=0){
+            result=language.left(i);
+        }
+    }
+    return result;
 }
 
 /*!
@@ -892,4 +770,3 @@ void GrammarCheckLanguageToolJSON::finished(QNetworkReply *nreply)
     }
 }
 
-#undef PRECEED_WITH_SPACES
