@@ -11,9 +11,6 @@
 namespace Parsing {
 
 
-//const int RUNAWAYLIMIT = 30; // limit lines to process multi-line arguments in order to prevent processing to the end of document if the argument is unclosed
-
-
 /*!
  * Realizes the first pass lexing
  * Following functionality is implemented:
@@ -87,6 +84,13 @@ TokenList simpleLexLatexLine(QDocumentLineHandle *dlh)
 					continue;
 				}
 				if (c.isLetter() && present.type == Token::number) {
+                    // special case 0x... 0b....
+                    if((c=='x' || c=='b')   && i-present.start==1 && s[present.start]=='0'){
+                        continue;
+                    }
+                    if(QString("abcdef").contains(c.toLower()) && s[present.start]=='0' && s[present.start+1]=='x'){
+                        continue;
+                    }
 					present.length = i - present.start;
 					lexed.append(present);
 					present.start = i;
@@ -146,7 +150,7 @@ TokenList simpleLexLatexLine(QDocumentLineHandle *dlh)
 }
 
 
-bool latexDetermineContexts2(QDocumentLineHandle *dlh, TokenStack &stack, CommandStack &commandStack, const LatexParser &lp)
+bool latexDetermineContexts2(QDocumentLineHandle *dlh, TokenStack &stack, CommandStack &commandStack, const QSharedPointer<LatexParser> lp)
 {
 	if (!dlh)
 	    return false;
@@ -172,6 +176,8 @@ bool latexDetermineContexts2(QDocumentLineHandle *dlh, TokenStack &stack, Comman
     int commentStart=-1;
 	QString keyName;
 
+    bool unknownCommandsPresent = false;
+
 	int lineLength=line.length();
 
 	for (int i = 0; i < tl.length(); i++) {
@@ -206,6 +212,7 @@ bool latexDetermineContexts2(QDocumentLineHandle *dlh, TokenStack &stack, Comman
                     tk1.start=tk.start;
                     tk1.length=1;
                     tk1.type=Token::verbatim;
+                    tk1.dlh=tk.dlh;
                     tk.type=Token::symbol;
                     tk.subtype=Token::verbatimStop;
                     tk.level = level;
@@ -249,7 +256,7 @@ bool latexDetermineContexts2(QDocumentLineHandle *dlh, TokenStack &stack, Comman
             }
             if (tk2.type == Token::openBrace && closingFound) {
                 QString env = line.mid(tk3.start, tk_closing.start-tk3.start);
-                if (lp.possibleCommands["%verbatimEnv"].contains(env)) { // incomplete check if closing corresponds to open !
+                if (lp->possibleCommands["%verbatimEnv"].contains(env)) { // incomplete check if closing corresponds to open !
                     Token verbatimStart=stack.top();
                     // second option, env in optionalCommandName
                     if(verbatimStart.optionalCommandName.isEmpty() || verbatimStart.optionalCommandName==env){
@@ -330,8 +337,8 @@ bool latexDetermineContexts2(QDocumentLineHandle *dlh, TokenStack &stack, Comman
                 tk.subtype = stack.top().subtype;
                 if (tk.subtype == Token::keyValArg && lastEqual > -1) {
                     tk.subtype = Token::keyVal_val;
-                    if (!commandStack.isEmpty() && lp.commandDefs.contains(commandStack.top().optionalCommandName + "/" + keyName)) {
-                        CommandDescription cd = lp.commandDefs.value(commandStack.top().optionalCommandName + "/" + keyName);
+                    if (!commandStack.isEmpty() && lp->commandDefs.contains(commandStack.top().optionalCommandName + "/" + keyName)) {
+                        CommandDescription cd = lp->commandDefs.value(commandStack.top().optionalCommandName + "/" + keyName);
                         tk.subtype = cd.argTypes.value(0, Token::keyVal_val);
                     }
                 }
@@ -342,7 +349,7 @@ bool latexDetermineContexts2(QDocumentLineHandle *dlh, TokenStack &stack, Comman
                 //possible command argument without brackets
                 CommandDescription &cd = commandStack.top();
                 if (cd.args > 0) {
-                    cd.optionalArgs = 0; // no optional arguments after mandatory
+                    //cd.optionalArgs = 0; // relax no optional arguments after mandatory, e.g. \newcommand\abc[1]{adadf}, #3073
                     cd.bracketArgs = 0;
                     cd.args--;
                     tk.subtype = cd.argTypes.takeFirst();
@@ -353,8 +360,8 @@ bool latexDetermineContexts2(QDocumentLineHandle *dlh, TokenStack &stack, Comman
                     commandStack.pop();
                 }
             }
-            if (lp.commandDefs.contains(command) && tk.subtype != Token::definition) {
-                CommandDescription cd = lp.commandDefs.value(command);
+            if (lp->commandDefs.contains(command) && tk.subtype != Token::definition) {
+                CommandDescription cd = lp->commandDefs.value(command);
                 cd.level = level;
                 if(cd.bracketCommand){
                     //command like \left
@@ -375,8 +382,12 @@ bool latexDetermineContexts2(QDocumentLineHandle *dlh, TokenStack &stack, Comman
                     commandStack.push(cd);
                 }
             } else {
-                if(tk.type==Token::command){
-                    tk.type = Token::commandUnknown;
+                if(tk.type==Token::command && tk.subtype == Token::none){
+                    if(command!="\\\\"){
+                        // skip "\\"
+                        tk.type = Token::commandUnknown;
+                        unknownCommandsPresent=true;
+                    }
                 }
             }
             lexed << tk;
@@ -444,7 +455,10 @@ bool latexDetermineContexts2(QDocumentLineHandle *dlh, TokenStack &stack, Comman
                     tk.argLevel = ConfigManager::RUNAWAYLIMIT; // run-away prevention, needs to be >0 as otherwise closing barces are misinterpreted
                     if (!stack.isEmpty()) {
                         tk.subtype = stack.top().subtype;
-                        if(tk.subtype==Token::keyValArg){
+                        if(tk.subtype==Token::text){
+                            tk.subtype=Token::none; //avoid assignening text subtype to just arbitrary braces inside an argument, see #3040 (#2603)
+                        }
+                        if(stack.top().subtype==Token::keyValArg){
                             // still the generic argument, needs to be broken down to key or val
                             if(lastComma>0){
                                 // -> val
@@ -517,9 +531,9 @@ bool latexDetermineContexts2(QDocumentLineHandle *dlh, TokenStack &stack, Comman
                             if (tk2.type == Token::beginEnv) {
                                 // special treatment for \begin ...
                                 QString env = line.mid(tk2.start, tk2.length);
-                                CommandDescription cd = lp.commandDefs.value("\\begin{" + env + "}", CommandDescription());
+                                CommandDescription cd = lp->commandDefs.value("\\begin{" + env + "}", CommandDescription());
                                 // special treatment for verbatim
-                                if (lp.possibleCommands["%verbatimEnv"].contains(env)) {
+                                if (lp->possibleCommands["%verbatimEnv"].contains(env)) {
                                     if(cd.args==1 && cd.optionalArgs==1 && i<(tl.length()-1) && tl[i+1].type==Token::openSquare){ // next Token needs to be [ i.e. optional arg, otherwise start verbatim directly
                                         // special treatment for \begin{abc}[...]
                                         cd.verbatimAfterOptionalArg=true;
@@ -571,6 +585,10 @@ bool latexDetermineContexts2(QDocumentLineHandle *dlh, TokenStack &stack, Comman
                     tk.subtype=tk1.subtype;
                     level=tk1.level; // restore original level
                     lexed.append(tk);
+                    // clean up command stack (unrealized arguments)
+                    while (!commandStack.isEmpty() && commandStack.top().level > level) {
+                        commandStack.pop();
+                    }
                 }
                 if (!commandStack.isEmpty() && commandStack.top().level == level) {
                     CommandDescription cd = commandStack.top();
@@ -619,6 +637,7 @@ bool latexDetermineContexts2(QDocumentLineHandle *dlh, TokenStack &stack, Comman
                         Token tk0;
                         tk0.start = tk.start;
                         tk0.length = 0;
+                        tk0.dlh=dlh;
                         tk0.type = Token::keyVal_val;
                         tk0.subtype = Token::keyVal_val;
                         tk0.level = level;
@@ -697,8 +716,8 @@ bool latexDetermineContexts2(QDocumentLineHandle *dlh, TokenStack &stack, Comman
                             }
                         }
                     }
-                    if (!commandStack.isEmpty() && lp.commandDefs.contains(commandStack.top().optionalCommandName + "/" + keyName)) {
-                        CommandDescription cd = lp.commandDefs.value(commandStack.top().optionalCommandName + "/" + keyName);
+                    if (!commandStack.isEmpty() && lp->commandDefs.contains(commandStack.top().optionalCommandName + "/" + keyName)) {
+                        CommandDescription cd = lp->commandDefs.value(commandStack.top().optionalCommandName + "/" + keyName);
                         tk.type = cd.argTypes.value(0, Token::keyVal_val); // only types can be set in key_val as they need to be recognized later
                         if(!lexed.isEmpty() && lexed.last().type==tk.type && lexed.last().subtype==tk.subtype){
                             lexed.last().length=tk.start+tk.length-lexed.last().start;
@@ -818,9 +837,7 @@ bool latexDetermineContexts2(QDocumentLineHandle *dlh, TokenStack &stack, Comman
     }
 
     dlh->setCookie(QDocumentLine::LEXER_COOKIE, QVariant::fromValue<TokenList>(lexed));
-    // run-away prevention
-    // reduce argLevel by 1, remove all elements with level <0
-    // TODO: needs to be applied on commandStack as well !!!
+
     for (int i = 0; i < stack.size(); i++) {
         if (stack[i].type == Token::verbatim)
             continue;
@@ -833,6 +850,9 @@ bool latexDetermineContexts2(QDocumentLineHandle *dlh, TokenStack &stack, Comman
     dlh->setCookie(QDocumentLine::LEXER_REMAINDER_COOKIE, QVariant::fromValue<TokenStack>(stack));
     dlh->setCookie(QDocumentLine::LEXER_COMMANDSTACK_COOKIE, QVariant::fromValue<CommandStack>(commandStack));
     dlh->setCookie(QDocumentLine::LEXER_COMMENTSTART_COOKIE, QVariant::fromValue<QPair<int,int> >({commentStart, Token::unknownComment}));
+    dlh->setFlag(QDocumentLine::lexedPass2InComplete,unknownCommandsPresent);
+    dlh->setFlag(QDocumentLine::lexedPass2Complete,!unknownCommandsPresent);
+    dlh->setFlag(QDocumentLine::argumentsParsed,false);
     dlh->unlock();
 
     bool remainderChanged = (stack != oldRemainder) || (commandStack != oldCommandStack) ;
@@ -1240,12 +1260,9 @@ TokenStack getContext(QDocumentLineHandle *dlh, int pos)
 		if (tk.start > pos) {
 			break;
 		}
-		if (Token::tkOpen().contains(tk.type)) {
-			stack.push(tk);
-		}
         if (Token::tkClose().contains(tk.type) && !stack.isEmpty() ) {
             if (stack.top().type == Token::opposite(tk.type) && (tk.start<pos)) {
-				stack.pop();
+                stack.pop();
 			}
             continue;
         }
@@ -1372,7 +1389,7 @@ Token getCommandTokenFromToken(TokenList tl, Token tk)
  * \param column
  * \return 512 if token at column is 'width'
  */
-int getCompleterContext(QDocumentLineHandle *dlh, int column)
+EnumsTokenType::TokenType getCompleterContext(QDocumentLineHandle *dlh, int column)
 {
 	TokenStack ts = getContext(dlh, column);
 	Token tk;
@@ -1386,19 +1403,11 @@ int getCompleterContext(QDocumentLineHandle *dlh, int column)
 		}
 	}
 
-	Token::TokenType type = tk.type;
+    EnumsTokenType::TokenType type = tk.type;
 	if (tk.subtype != Token::none && tk.subtype != Token::keyVal_val)
 		type = tk.subtype;
 
-	int result = 0;
-	switch (type) {
-	case Token::width:
-		result = 512;
-		break;
-	default:
-		;
-	}
-	return result;
+    return type;
 }
 
 }  // namespace Parsing
