@@ -329,8 +329,8 @@ bool LatexStyleParser::parseLineLet(QStringList &results, const QString &line)
 
 bool LatexStyleParser::parseLineCommand(QStringList &results, const QString &line)
 {
-	static const QRegExp rxComBrace("\\\\(newcommand|providecommand|DeclareRobustCommand)\\*?\\s*\\{(\\\\\\w+)\\}\\s*\\[?(\\d+)?\\]?(?:\\s*\\[([^\\]]*)\\])?");
-	static const QRegExp rxComNoBrace("\\\\(newcommand|providecommand|DeclareRobustCommand)\\*?\\s*(\\\\\\w+)\\s*\\[?(\\d+)?\\]?(?:\\s*\\[([^\\]]*)\\])?");
+    static const QRegExp rxComBrace("\\\\(newcommand|providecommand|DeclareRobustCommand|algnewcommand)\\*?\\s*\\{(\\\\\\w+)\\}\\s*\\[?(\\d+)?\\]?(?:\\s*\\[([^\\]]*)\\])?");
+    static const QRegExp rxComNoBrace("\\\\(newcommand|providecommand|DeclareRobustCommand|algnewcommand)\\*?\\s*(\\\\\\w+)\\s*\\[?(\\d+)?\\]?(?:\\s*\\[([^\\]]*)\\])?");
 	const QRegExp *pRx;
 
 	if (rxComBrace.indexIn(line) != -1) {
@@ -391,10 +391,19 @@ bool LatexStyleParser::parseLineInput(QStringList &results, const QString &line,
 		return false;
 	}
 	QString name = rxInput.cap(1);
-	name = kpsewhich(name);
-	if (!name.isEmpty() && name != fileName) { // avoid indefinite loops
-		results << readPackage(name, parsedPackages);
-	}
+    // check if included is already known as cwl
+    QFileInfo fi(name);
+    QString baseName=fi.baseName();
+
+    if(fi.exists("cwl:"+baseName+".cwl")){
+        // refer to already provided cwl
+        results<<"#include:"+baseName;
+    }else{
+        name = kpsewhich(name);
+        if (!name.isEmpty() && name != fileName) { // avoid indefinite loops
+            results << readPackage(name, parsedPackages);
+        }
+    }
 	return true;
 }
 
@@ -708,7 +717,7 @@ QStringList LatexStyleParser::readPackage(QString fileName, QStringList &parsedP
 		QString line;
 		bool inRequirePackage = false;
 		while (!stream.atEnd()) {
-			line = LatexParser::cutComment(stream.readLine());
+            line = cutComment(stream.readLine());
 			results << parseLine(line, inRequirePackage, parsedPackages, fileName);
 		}
 	}
