@@ -89,7 +89,11 @@ class QCE_EXPORT QDocumentLine
 			
 			LayoutDirty			= 16,
 			FormatsApplied		= 32,
-			LayoutedByQTextLayout	= 64
+            LayoutedByQTextLayout	= 64,
+            lexedPass1 = 128,
+            lexedPass2InComplete = 256,
+            lexedPass2Complete = 512,
+            argumentsParsed = 1024,
 		};
 		
         Q_DECLARE_FLAGS(States, State)
@@ -187,7 +191,7 @@ class QCE_EXPORT QDocumentLine
         int getFormatAt(int pos) const;
         int getCachedFormatAt(int pos) const;
 		
-		const QVector<QParenthesis>& parentheses() const;
+		const QVector<QParenthesis> parentheses() const;
 		void setParentheses(const QVector<QParenthesis>& parentheses);
 		
 		inline QDocumentLineHandle* handle() const
