@@ -64,8 +64,23 @@ void SyntaxCheck::putLine(QDocumentLineHandle *dlh, StackEnvironment previous, T
 	mLinesEnqueuedCounter.ref();
 	mLinesLock.unlock();
 	//avoid reading of any results before this execution is stopped
-	//mResultLock.lock(); not possible under windows
-	mLinesAvailable.release();
+    //mResultLock.lock(); not possible under windows
+    mLinesAvailable.release();
+}
+/*!
+ * \brief remove all outstanding unckecked lines
+ * Clear queue as all lines are rechecked
+ */
+void SyntaxCheck::clearQueue()
+{
+    mLinesLock.lock();
+    mLines.clear();
+    int n=mLinesAvailable.available();
+    if(n>0){
+        mLinesAvailable.acquire(n-1);
+    }
+    mLinesLock.unlock();
+    // what to do with the semaphore ?
 }
 
 /*!
@@ -82,7 +97,7 @@ void SyntaxCheck::stop()
 */
 void SyntaxCheck::run()
 {
-	ltxCommands = new LatexParser();
+    ltxCommands = QSharedPointer<LatexParser>::create();
 
 	forever {
 		//wait for enqueued lines
@@ -93,7 +108,9 @@ void SyntaxCheck::run()
 			mLtxCommandLock.lock();
 			if (newLtxCommandsAvailable) {
 				newLtxCommandsAvailable = false;
-				*ltxCommands = newLtxCommands;
+                if(newLtxCommands){
+                    *ltxCommands = *newLtxCommands;
+                }
                 speller=newSpeller;
                 mReplacementList=newReplacementList;
                 mFormatList=newFormatList;
@@ -103,7 +120,11 @@ void SyntaxCheck::run()
 
 		// get Linedata
 		mLinesLock.lock();
-		SyntaxLine newLine = mLines.dequeue();
+        if(mLines.isEmpty()){
+            mLinesLock.unlock();
+            continue;
+        }
+        SyntaxLine newLine = mLines.dequeue();
 		mLinesLock.unlock();
 		// do syntax check
 		newLine.dlh->lockForRead();
@@ -166,7 +187,6 @@ void SyntaxCheck::run()
 		newLine.dlh->deref(); //if deleted, delete now
 	}
 
-	delete ltxCommands;
 	ltxCommands = nullptr;
 }
 
@@ -241,12 +261,13 @@ QString SyntaxCheck::getErrorAt(QDocumentLineHandle *dlh, int pos, StackEnvironm
 * \brief set latex commands which are referenced for syntax checking
 * \param cmds
 */
-void SyntaxCheck::setLtxCommands(const LatexParser &cmds)
+void SyntaxCheck::setLtxCommands(QSharedPointer<LatexParser> cmds)
 {
 	if (stopped) return;
 	mLtxCommandLock.lock();
 	newLtxCommandsAvailable = true;
-	newLtxCommands = cmds;
+    newLtxCommands = QSharedPointer<LatexParser>::create();
+    *newLtxCommands = *cmds;
     mLtxCommandLock.unlock();
 }
 
@@ -362,23 +383,52 @@ int SyntaxCheck::topEnv(const QString &name, const StackEnvironment &envs, const
 * \param id if >=0 check if the env has the given id.
 * \return environment id of  found env otherwise 0
 */
-int SyntaxCheck::containsEnv(const LatexParser &parser, const QString &name, const StackEnvironment &envs, const int id)
+int SyntaxCheck::containsEnv(const QString &name, const StackEnvironment &envs, const int id)
 {
 	for (int i = envs.size() - 1; i > -1; --i) {
 		Environment env = envs.at(i);
 		if (env.name == name) {
 			if (id < 0 || env.id == id)
 				return env.id;
-		}
-		if (id < 0 && parser.environmentAliases.contains(env.name)) {
-			QStringList altEnvs = parser.environmentAliases.values(env.name);
+        }
+        if (id < 0 && ltxCommands->environmentAliases.contains(env.name)) {
+            QStringList altEnvs = ltxCommands->environmentAliases.values(env.name);
 			foreach (const QString &altEnv, altEnvs) {
 				if (altEnv == name)
 					return env.id;
 			}
 		}
 	}
-	return 0;
+    return 0;
+}
+/*!
+ * \brief check if math env is active
+ *
+ * Similar to containsEnv, but determines if math is active as it can be disabled by a virtual text env
+ * e.g. $abc \textbf{text}$
+ * \param parser reference to LatexParser. It is used to access environment aliases, e.g. equation is also a math environment
+ * \param envs stack of environements
+ * \return math is active (true) or not (false)
+ */
+bool SyntaxCheck::checkMathEnvActive(const StackEnvironment &envs)
+{
+    for (int i = envs.size() - 1; i > -1; --i) {
+        Environment env = envs.at(i);
+        if (env.name == "math") {
+                return true;
+        }
+        if (env.name == "text") {
+                return false;
+        }
+        if (ltxCommands->environmentAliases.contains(env.name)) {
+            QStringList altEnvs = ltxCommands->environmentAliases.values(env.name);
+            foreach (const QString &altEnv, altEnvs) {
+                if (altEnv == "math")
+                    return true;
+            }
+        }
+    }
+    return false;
 }
 
 /*!
@@ -389,8 +439,12 @@ int SyntaxCheck::containsEnv(const LatexParser &parser, const QString &name, con
 */
 bool SyntaxCheck::checkCommand(const QString &cmd, const StackEnvironment &envs)
 {
-	for (int i = 0; i < envs.size(); ++i) {
+    bool textOrMathEnvUsed=false;
+    for (int i = envs.size()-1; i > -1; --i) {
 		Environment env = envs.at(i);
+        if(textOrMathEnvUsed &&(env.name=="math" || env.name=="text" )){
+            continue; // only the lowest text/math is valid as they can be used alternately
+        }
 		if (ltxCommands->possibleCommands.contains(env.name) && ltxCommands->possibleCommands.value(env.name).contains(cmd))
 			return true;
 		if (ltxCommands->environmentAliases.contains(env.name)) {
@@ -400,6 +454,9 @@ bool SyntaxCheck::checkCommand(const QString &cmd, const StackEnvironment &envs)
 					return true;
 			}
 		}
+        if(env.name=="math" || env.name=="text" ){
+            textOrMathEnvUsed=true; // only the lowest text/math is valid as they can be used alternately
+        }
 	}
 	return false;
 }
@@ -437,7 +494,7 @@ void SyntaxCheck::markUnclosedEnv(Environment env)
 	dlh->lockForWrite();
 	if (dlh->getCurrentTicket() == env.ticket) {
 		QString line = dlh->text();
-		line = ltxCommands->cutComment(line);
+        line = cutComment(line);
 		QString cmd = "\\begin{" + env.name + "}";
 		int index = line.lastIndexOf(cmd);
 		if (index >= 0) {
@@ -503,7 +560,7 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
             */
         }
     }
-
+    QVector<QParenthesis> m_parens;
     // check command-words
 	for (int i = 0; i < tl.length(); i++) {
         Token &tk = tl[i];
@@ -546,7 +603,7 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
 			QString word = line.mid(tk.start, tk.length);
 			QStringList forbiddenSymbols;
 			forbiddenSymbols<<"^"<<"_";
-            if(forbiddenSymbols.contains(word) && !containsEnv(*ltxCommands, "math", activeEnv) && tk.subtype!=Token::formula){
+            if(forbiddenSymbols.contains(word) && !checkMathEnvActive(activeEnv) && tk.subtype!=Token::formula){
 				Error elem;
 				elem.range = QPair<int, int>(tk.start, tk.length);
 				elem.type = ERR_MathCommandOutsideMath;
@@ -564,7 +621,7 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
             }else{
                 elem.format=mFormatList["math"];
             }
-            if(tk.type==Token::braces){
+            if(tk.type==Token::braces || tk.type==Token::openBrace){
                 // add to active env
                 Environment env;
                 env.name = "math";
@@ -574,12 +631,39 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
                 env.level = tk.level;
                 env.startingColumn=tk.start+1;
                 env.endingColumn=tk.start+tk.length-1;
+                if(tk.type==Token::openBrace){
+                    env.endingColumn=-1;
+                }
+                // avoid stacking same env (e.g. braces in braces, see #2411 )
+                Environment topEnv=activeEnv.top();
+                if(topEnv.name!=env.name)
+                    activeEnv.push(env);
+            }
+            if(tk.type==Token::closeBrace){
+                if(activeEnv.top().name=="math"){
+                    activeEnv.pop();
+                }
+            }
+            newRanges.append(elem);
+        }
+        // force text != math when text command is used, i.e. \textbf in math env, see #2603
+        if(tk.subtype==Token::text){
+            if(tk.type==Token::braces){
+                // add to active env
+                // invalidates math env as active
+                Environment env;
+                env.name = "text";
+                env.id = 1; // to be changed
+                env.dlh = dlh;
+                env.ticket = ticket;
+                env.level = tk.level;
+                env.startingColumn=tk.start+1;
+                env.endingColumn=tk.start+tk.length-1;
                 // avoid stacking same env (e.g. braces in braces, see #2411 )
                 Environment topEnv=activeEnv.top();
                 if(topEnv.name!=env.name)
                     activeEnv.push(env);
             }
-            newRanges.append(elem);
         }
         // spell checking
         if (speller->inlineSpellChecking && tk.type == Token::word && (tk.subtype == Token::text || tk.subtype == Token::title || tk.subtype == Token::shorttitle || tk.subtype == Token::todo || tk.subtype == Token::none)  && speller) {
@@ -609,12 +693,12 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
                 }
             }
             word = latexToPlainWordwithReplacementList(word, mReplacementList); //remove special chars
-            if (speller->hideNonTextSpellingErrors && (containsEnv(*ltxCommands, "math", activeEnv)||containsEnv(*ltxCommands, "picture", activeEnv)) && tk.subtype!=Token::text){
+            if (speller->hideNonTextSpellingErrors && (checkMathEnvActive(activeEnv)||containsEnv("picture", activeEnv)) ){
                 word.clear();
                 tk.ignoreSpelling=true;
             }else{
                 tk.ignoreSpelling=false;
-                if(containsEnv(*ltxCommands, "math", activeEnv)){
+                if(containsEnv("math", activeEnv)){
                     // in math env, highlight as math-text !
                     Error elem;
                     elem.type = ERR_highlight;
@@ -656,6 +740,8 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
                 elem.format=mFormatList["&math"];
                 elem.range = QPair<int, int>(tk.start, tk.length);
                 newRanges.append(elem);
+                QParenthesis p(61,17,tk.start,tk.length);
+                m_parens.append(p);
                 continue;
 			}
 			if (ltxCommands->mathStopCommands.contains(word) && !activeEnv.isEmpty() && activeEnv.top().name == "math") {
@@ -678,6 +764,8 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
                     elem.format=mFormatList["&math"];
                     elem.range = QPair<int, int>(tk.start, tk.length);
                     newRanges.append(elem);
+                    QParenthesis p(61,18,tk.start,tk.length);
+                    m_parens.append(p);
 				}// ignore mismatching mathstop commands
 				continue;
 			}
@@ -719,7 +807,7 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
                     }
                 }
             }
-			if (ltxCommands->possibleCommands["user"].contains(word) || ltxCommands->customCommands.contains(word))
+            if (ltxCommands->possibleCommands["user"].contains(word))
 				continue;
 			if (!checkCommand(word, activeEnv)) {
 				Error elem;
@@ -775,7 +863,7 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
                                     }
                                 }
                             }
-                            elem.range = QPair<int, int>(start, end);
+                            elem.range = QPair<int, int>(start, end-start);
                             elem.type = ERR_highlight;
                             elem.format=mFormatList.value(key);
                             newRanges.append(elem);
@@ -839,6 +927,13 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
 						}
 					}
 				}
+                if(option.contains("colspec")){
+                    const QRegularExpression re{"^(.*colspec\\s*[=]\\s*\\{)(.*)\\}"};
+                    const QRegularExpressionMatch match = re.match(option);
+                    if (match.hasMatch()) {
+                        option = match.captured(2);
+                    }
+                }
 				QSet<QString> translationMap=ltxCommands->possibleCommands.value("%columntypes");
 				QStringList res = LatexTables::splitColDef(option);
 				QStringList res2;
@@ -862,7 +957,10 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
 
 
         if (tk.type == Token::command) {
-			QString word = line.mid(tk.start, tk.length);
+            QString word = line.mid(tk.start, tk.length);
+            if (word.contains('@')) {
+                continue; //ignore commands containg @
+            }
 			if(!tk.optionalCommandName.isEmpty()){
 				word=tk.optionalCommandName;
 			}
@@ -876,7 +974,7 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
 				}
 			}
             // special treatment for & in math
-            if(word=="&" && containsEnv(*ltxCommands, "math", activeEnv)){
+            if(word=="&" && containsEnv("math", activeEnv)){
                 Error elem;
                 elem.range = QPair<int, int>(tk.start, tk.length);
                 elem.type = ERR_highlight;
@@ -901,6 +999,8 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
                 elem.format=mFormatList["&math"];
                 elem.range = QPair<int, int>(tk.start, tk.length);
                 newRanges.append(elem);
+                QParenthesis p(61,17,tk.start,tk.length);
+                m_parens.append(p);
 				continue;
 			}
 			if (ltxCommands->mathStopCommands.contains(word) && !activeEnv.isEmpty() && activeEnv.top().name == "math") {
@@ -923,6 +1023,8 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
                     elem.format=mFormatList["&math"];
                     elem.range = QPair<int, int>(tk.start, tk.length);
                     newRanges.append(elem);
+                    QParenthesis p(61,18,tk.start,tk.length);
+                    m_parens.append(p);
 				}// ignore mismatching mathstop commands
 				continue;
 			}
@@ -1008,7 +1110,7 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
                 }
             }
 
-			if (ltxCommands->possibleCommands["user"].contains(word) || ltxCommands->customCommands.contains(word))
+            if (ltxCommands->possibleCommands["user"].contains(word))
 				continue;
 
 			if (!checkCommand(word, activeEnv)) {
@@ -1126,8 +1228,8 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
 		if (tk.subtype == Token::keyVal_val) {
 			//figure out keyval
 			QString word = line.mid(tk.start, tk.length);
-            if(word=="{"){
-                continue; // assume open brace is always valid
+            if(word=="{" || tk.type==Token::braces){
+                continue; // assume open brace is always valid or element in braces can't be checked (will get here again w/o braces)
             }
 			// first get command
             QString command = tk.optionalCommandName;
@@ -1189,6 +1291,13 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
 					}
                     if(options.startsWith("%")){
                         if (!ltxCommands->possibleCommands[options].contains(word)) {
+                            // special treatement for %color (mix)
+                            if(options=="%color"){
+                                if(word=="!") continue;
+                                bool ok;
+                                word.toInt(&ok);
+                                if(ok) continue; // number !
+                            }
                             Error elem;
                             elem.range = QPair<int, int>(tk.start, tk.length);
                             elem.type = ERR_unrecognizedKeyValues;
@@ -1207,6 +1316,27 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
 			}
 		}
 	}
+    if(!m_parens.isEmpty()){
+        // merge original parenthesis vector with new additions
+        // skip duplicates
+        QVector<QParenthesis> original_parens=dlh->parenthesis();
+        QVector<QParenthesis> result;
+        int i=0;
+        for(int j=0;j<m_parens.length();++j){
+            while(i<original_parens.size() && original_parens[i].offset<m_parens[j].offset){
+                result<<original_parens[i];
+                ++i;
+            }
+            if(i<original_parens.size() && m_parens[j].offset==original_parens[i].offset){
+                ++i;
+            }
+            result<<m_parens[j];
+        }
+        for(;i<original_parens.size();++i){
+            result<<original_parens[i];
+        }
+        dlh->setParenthesis(result);
+    }
     if(!activeEnv.isEmpty()){
         //check active env for env highlighting (math,verbatim)
         QStack<Environment>::Iterator it=activeEnv.begin();
@@ -1217,7 +1347,11 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
                 if(altEnvs.contains(key)){
                     Error elem;
                     int start= it->dlh==dlh ? it->startingColumn : 0;
-                    elem.range = QPair<int, int>(start, commentStart>=0 ? commentStart-start : line.length()-start);
+                    int length= it->endingColumn-start;
+                    if(length<0){
+                            length= commentStart>=0 ? commentStart-start : line.length()-start;
+                    }
+                    elem.range = QPair<int, int>(start, length);
                     elem.type = ERR_highlight;
                     elem.format=mFormatList.value(key);
                     newRanges.prepend(elem);  // draw this first and then other on top (e.g. keyword highlighting) !
