@@ -99,18 +99,20 @@ public:
     explicit SyntaxCheck(QObject *parent = nullptr);
 
     void putLine(QDocumentLineHandle *dlh, StackEnvironment previous, TokenStack stack, bool clearOverlay = false,int hint=-1);
+    void clearQueue();
 	void stop();
 	void setErrFormat(int errFormat);
     QString getErrorAt(QDocumentLineHandle *dlh, int pos, StackEnvironment previous, TokenStack stack);
 #ifndef NO_TESTS
 	void waitForQueueProcess(void);
 #endif
-	static int containsEnv(const LatexParser &parser, const QString &name, const StackEnvironment &envs, const int id = -1);
+    int containsEnv(const QString &name, const StackEnvironment &envs, const int id = -1);
+    bool checkMathEnvActive(const StackEnvironment &envs);
 	int topEnv(const QString &name, const StackEnvironment &envs, const int id = -1);
 	bool checkCommand(const QString &cmd, const StackEnvironment &envs);
 	static bool equalEnvStack(StackEnvironment env1, StackEnvironment env2);
 
-	void setLtxCommands(const LatexParser &cmds);
+    void setLtxCommands(QSharedPointer<LatexParser> cmds);
     void setSpeller(SpellerUtility *su);
     void setReplacementList(QMap<QString, QString> replacementList);
     void setFormats(QMap<QString, int> formatList);
@@ -133,9 +135,9 @@ private:
 	bool stopped;
     bool mSyntaxChecking; //! show/hide syntax errors
     int syntaxErrorFormat;
-	LatexParser *ltxCommands;
+    QSharedPointer<LatexParser> ltxCommands;
 
-	LatexParser newLtxCommands;
+    QSharedPointer<LatexParser> newLtxCommands;
 	bool newLtxCommandsAvailable;
 	QMutex mLtxCommandLock;
 	bool stackContainsDefinition(const TokenStack &stack) const;
