@@ -7,7 +7,7 @@
 #include "configmanager.h"
 
 QSet<QString> LatexTables::tabularNames = QSet<QString>() << "tabular" << "array" << "longtable" << "supertabular" << "tabu" << "longtabu"
-                                        << "IEEEeqnarray" << "xtabular" << "xtabular*" << "mpxtabular" << "mpxtabular*";
+                                                          << "IEEEeqnarray" << "xtabular" << "xtabular*" << "mpxtabular" << "mpxtabular*"<<"tblr"<<"longtblr"<<"talltblr";
 QSet<QString> LatexTables::tabularNamesWithOneOption = QSet<QString>() << "tabular*" << "tabularx" << "tabulary";
 QSet<QString> LatexTables::mathTables = QSet<QString>() << "align" << "align*" << "array" << "matrix" << "matrix*" << "bmatrix" << "bmatrix*"
                                       << "Bmatrix" << "Bmatrix*" << "pmatrix" << "pmatrix*" << "vmatrix" << "vmatrix*"
@@ -279,7 +279,7 @@ void LatexTables::removeColumn(QDocument *doc, const int lineNumber, const int c
 			if (add > 1) {
 				//multicolumn handling
 				QStringList values;
-				LatexParser::resolveCommandOptions(selText, 0, values);
+                resolveCommandOptions(selText, 0, values);
 				values.takeFirst();
 				values.prepend(QString("{%1}").arg(add - 1));
 				cur.movePosition(1, QDocumentCursor::PreviousCharacter, QDocumentCursor::KeepAnchor);
@@ -361,7 +361,7 @@ int LatexTables::findNextToken(QDocumentCursor &cur, QStringList tokens, bool ke
 		if (backwards) {
 			offset = line.length();
 		}
-		line = LatexParser::cutComment(line);
+        line = cutComment(line);
 		if (backwards) {
 			offset = offset - line.length();
             std::reverse(line.begin(),line.end());
@@ -446,7 +446,7 @@ QString LatexTables::getDef(QDocumentCursor &cur)
 	if (pos > -1) {
 		QStringList values;
 		QList<int> starts;
-		LatexParser::resolveCommandOptions(line, pos, values, &starts);
+        resolveCommandOptions(line, pos, values, &starts);
 		QString env = values.takeFirst();
 		pos = starts.takeFirst();
 		if (!env.startsWith("{") || !env.endsWith("}")) return QString();
@@ -459,7 +459,7 @@ QString LatexTables::getDef(QDocumentCursor &cur)
 			if (endExtra >= 0 && endExtra > startExtra) {
 				QString textHelper = line;
 				textHelper.remove(startExtra, endExtra - startExtra); // remove to/spread definition
-				LatexParser::resolveCommandOptions(textHelper, pos, values, &starts);
+                resolveCommandOptions(textHelper, pos, values, &starts);
 				for (int i = 1; i < starts.count(); i++) {
 					starts[i] += endExtra - startExtra;
 				}
@@ -482,9 +482,22 @@ QString LatexTables::getDef(QDocumentCursor &cur)
 				opt.chop(1);
 				cur.moveTo(c.lineNumber(), pos + 1);
 				cur.movePosition(opt.length(), QDocumentCursor::NextCharacter, QDocumentCursor::KeepAnchor);
+                break;
 			}
 		}
 	}
+    // in case of colspec, refine further
+    if(opt.contains("colspec")){
+        QRegularExpression re{"^(.*colspec\\s*[=]\\s*\\{)(.*)\\}"};
+        QRegularExpressionMatch match = re.match(opt);
+        if (match.hasMatch()) {
+            int offset=match.capturedLength(1);
+            QString matched = match.captured(2);
+            opt=matched;
+            cur.moveTo(c.lineNumber(), pos+1+offset);
+            cur.movePosition(opt.length(), QDocumentCursor::NextCharacter, QDocumentCursor::KeepAnchor);
+        }
+    }
 	return opt;
 }
 
@@ -498,7 +511,7 @@ int LatexTables::getNumberOfColumns(QDocumentCursor &cur)
 	int pos = line.indexOf("\\begin");
 	if (pos > -1) {
 		QStringList values;
-		LatexParser::resolveCommandOptions(line, pos, values);
+        resolveCommandOptions(line, pos, values);
 		return getNumberOfColumns(values);
 	}
 	return -1;
@@ -526,7 +539,9 @@ int LatexTables::getNumberOfColumns(QStringList values)
 			}
 			if (!opt.startsWith("{") || !opt.endsWith("}")) return -1;
 			opt = opt.mid(1);
-			opt.chop(1);
+            opt.chop(1);
+            // in case of colspec, refine further
+            opt=handleColSpec(opt);
 			//calculate number of columns ...
 			QStringList res = splitColDef(opt);
 			int cols = res.count();
@@ -549,7 +564,7 @@ bool LatexTables::inTableEnv(QDocumentCursor &cur)
 	int pos = line.indexOf("\\begin");
 	if (pos > -1) {
 		QStringList values;
-		LatexParser::resolveCommandOptions(line, pos, values);
+        resolveCommandOptions(line, pos, values);
 		QString env = values.takeFirst();
 		if (!env.startsWith("{") || !env.endsWith("}")) return -1;
 		env = env.mid(1);
@@ -570,11 +585,11 @@ int LatexTables::getNumOfColsInMultiColumn(const QString &str, QString *outAlign
 	//return the number of columns in mulitcolumn command
 	QStringList values;
 	QString zw = str.trimmed();
-	LatexParser::resolveCommandOptions(zw, 0, values);
+    resolveCommandOptions(zw, 0, values);
 	if (values.length() != 3) return -1;
 
-	if (outAlignment) *outAlignment = LatexParser::removeOptionBrackets(values.at(1));
-	if (outText) *outText = LatexParser::removeOptionBrackets(values.at(2));
+    if (outAlignment) *outAlignment = removeOptionBrackets(values.at(1));
+    if (outText) *outText = removeOptionBrackets(values.at(2));
 
 	zw = values.takeFirst();
 	if (zw.startsWith("{") && zw.endsWith("}")) {
@@ -888,12 +903,13 @@ void LatexTables::alignTableCols(QDocumentCursor &cur)
 		alignment = "l"; // may be more. But thats caught by the fallback (filling with additional "l").
 	}
 	// assume alignment in second arg except for the following environments (which have it in the third one)
-	else if (args.count() > 1 && tabularNames.contains(tableType)) {
-		alignment = args.at(1).value;
-	} else if (tabularNamesWithOneOption.contains(tableType)) {
-		if (args.count() < 3) alignment = ""; // incomplete definition -> fall back to defaults
-		else alignment = args.at(2).value;
-	} else return; // not a registered table environment
+    else if (tabularNamesWithOneOption.contains(tableType)) {
+        if (args.count() < 3) alignment = ""; // incomplete definition -> fall back to defaults
+        else alignment = args.at(2).value;
+    } else if (args.count() > 1 && tabularNames.contains(tableType)) {
+        alignment = args.at(1).value;
+    } else return; // not a registered table environment
+    alignment=handleColSpec(alignment);
 	int cellsEnd = text.indexOf("\\end{" + tableType);
 	if (cellsEnd < 0) return;
 	QString beginPart = text.left(cellsStart);
@@ -919,8 +935,26 @@ void LatexTables::alignTableCols(QDocumentCursor &cur)
 	for (int i = 0; i < content.count(); i++) {
 		result.append(indentation + content.at(i) + '\n');
 	}
-	result.append(indentation + endPart);
-	cur.replaceSelectedText(result);
+    result.append(indentation + endPart);
+    cur.replaceSelectedText(result);
+}
+
+/*!
+ * \brief if preamble uses colspec syntax, extract alignment, otherwise return original text
+ * \param opt
+ * \return refined preamble with alignment info only
+ */
+QString LatexTables::handleColSpec(QString opt)
+{
+    // in case of colspec, refine further
+    if(opt.contains("colspec")){
+        QRegularExpression re{"^(.*colspec\\s*[=]\\s*\\{)(.*)\\}"};
+        QRegularExpressionMatch match = re.match(opt);
+        if (match.hasMatch()) {
+            opt = match.captured(2);
+        }
+    }
+    return opt;
 }
 
 LatexTableModel::LatexTableModel(QObject *parent) : QAbstractTableModel(parent), metaLineCommandPos(0)
