@@ -304,68 +304,10 @@ void LatexParserTest::cutComment_simple()
 {
 	QFETCH(QString, in);
 	QFETCH(QString, out);
-	QString res = LatexParser::cutComment(in);
+    QString res = cutComment(in);
 	QEQUAL(res, out);
 }
 
-void LatexParserTest::test_findContext_data()
-{
-	QTest::addColumn<QString >("in");
-	QTest::addColumn<int>("pos");
-	QTest::addColumn<int>("out");
-
-	QTest::newRow("command") << "\\begin{test}" << 3 << 1;
-	QTest::newRow("content") << "\\begin{test}" << 8 << 3;
-	QTest::newRow("option") << "\\begin[abc]{test}" << 8 << 2;
-	QTest::newRow("content with option") << "\\begin[abc]{test}" << 13 << 3;
-	QTest::newRow("content with option2") << "\\begin[\\abc]{test}" << 14 << 3;
-	QTest::newRow("command with option") << "\\begin[abc]{test}" << 3 << 1;
-	QTest::newRow("nothing") << "\\begin{test}" << 0 << 0;
-}
-
-void LatexParserTest::test_findContext()
-{
-	QFETCH(QString, in);
-	QFETCH(int, pos);
-	QFETCH(int, out);
-	int res = LatexParser::getInstance().findContext(in, pos);
-	QEQUAL(res, out);
-}
-
-void LatexParserTest::test_findContext2_data()
-{
-	QTest::addColumn<QString >("in");
-	QTest::addColumn<int>("pos");
-	QTest::addColumn<int>("out");
-	QTest::addColumn<QString>("command");
-	QTest::addColumn<QString>("value");
-
-    QTest::newRow("command") << "\\begin{test}" << 3 << static_cast<int>(LatexParser::Command) << "\\begin" << "test";
-    QTest::newRow("content") << "\\begin{test}" << 8 << static_cast<int>(LatexParser::Environment) << "\\begin" << "test";
-    QTest::newRow("ref") << "\\ref{test}" << 8 << static_cast<int>(LatexParser::Reference) << "\\ref" << "test";
-    QTest::newRow("label") << "\\label{test}" << 8 << static_cast<int>(LatexParser::Label) << "\\label" << "test";
-    QTest::newRow("cite") << "\\cite{test}" << 8 << static_cast<int>(LatexParser::Citation) << "\\cite" << "test";
-    QTest::newRow("cite") << "\\cite{test}" << 3 << static_cast<int>(LatexParser::Command) << "\\cite" << "test";
-    QTest::newRow("abcd option") << "\\abcd{test}" << 7 << static_cast<int>(LatexParser::Option) << "\\abcd" << "test";
-    QTest::newRow("abcd option2") << "\\abcd[abc]{test}" << 12 << static_cast<int>(LatexParser::Option) << "\\abcd" << "test";
-    QTest::newRow("abcd option3") << "\\abcd[\\abc]{test}" << 12 << static_cast<int>(LatexParser::Option) << "\\abcd" << "test";
-}
-
-void LatexParserTest::test_findContext2()
-{
-	QFETCH(QString, in);
-	QFETCH(int, pos);
-	QFETCH(int, out);
-	QFETCH(QString, command);
-	QFETCH(QString, value);
-	QString cmd;
-	QString val;
-	LatexParser::ContextType res = LatexParser::getInstance().findContext(in, pos, cmd, val);
-    QEQUAL(static_cast<int>(res), out);
-	QEQUAL(cmd, command);
-	QEQUAL(val, value);
-}
-
 void LatexParserTest::test_resolveCommandOptions_data()
 {
 	QTest::addColumn<QString>("line");
@@ -395,7 +337,7 @@ void LatexParserTest::test_resolveCommandOptions()
 	QFETCH(bool, expectedComplete);
 	QStringList values;
 	QList<int> starts;
-	bool complete = LatexParser::resolveCommandOptions(line, column, values, &starts);
+    bool complete = resolveCommandOptions(line, column, values, &starts);
 	QEQUAL(values.length(), starts.length());
 	QEQUAL(values.join("|"), expectedValues.join("|"));
 	QVERIFY(starts == expectedStarts);
