@@ -9,6 +9,7 @@
 #include "latexparser/latexparser.h"
 #include "latexpackage.h"
 #include "testutil.h"
+#include "configmanager.h"
 #include <QtTest/QtTest>
 
 // shortcuts and semantic types
@@ -156,7 +157,7 @@ void LatexParsingTest::test_latexLexing_data() {
                                   << (Levels() << 0 << 1 << 1);
     QTest::newRow("text command with nested braces") << "\\textbf{text {abc}}"
                                   << (TTypes() << T::command << T::braces << T::word << T::braces << T::word)
-                                  << (STypes() << T::none << T::text << T::text << T::text << T::text)
+                                  << (STypes() << T::none << T::text << T::text << T::none << T::none)
                                   << (Starts() << 0 << 7 << 8 << 13 << 14)
                                   << (Length() << 7 << 12 << 4 << 5 << 3)
                                   << (Levels() << 0 << 1 << 1 << 1 << 1);
@@ -312,12 +313,19 @@ void LatexParsingTest::test_latexLexing_data() {
                                       << (Starts() << 0 << 1 << 7 << 12)
                                       << (Length() << 1 << 5 << 5 << 1)  // note: the brackets are ignored, they are not part of the command
                                       << (Levels() << 0 << 0 << 0 << 0);
+    QTest::newRow("unused argument in text command") << "\\textbf{\\textbf} text"
+                                     << (TTypes() << T::command << T::braces << T::command << T::word)
+                                     << (STypes() << T::none << T::text << T::text << T::none)
+                                     << (Starts() << 0 << 7 << 8 <<17)
+                                     << (Length() << 7 << 9 << 7 << 4)
+                                     << (Levels() << 0 << 1 << 1 << 0);
 }
 
 void LatexParsingTest::test_latexLexing() {
-    LatexParser lp = LatexParser::getInstance();
+    QSharedPointer<LatexParser> lp = QSharedPointer<LatexParser>::create();
+    *lp=LatexParser::getInstance();
     LatexPackage pkg_graphics = loadCwlFile("graphicx.cwl");
-    lp.commandDefs.unite(pkg_graphics.commandDescriptions);
+    lp->commandDefs.unite(pkg_graphics.commandDescriptions);
     QFETCH(QString,lines);
     QFETCH(TTypes, types);
     QFETCH(STypes, subtypes);
@@ -416,9 +424,10 @@ void LatexParsingTest::test_findCommandWithArgsFromTL_data() {
 }
 
 void LatexParsingTest::test_findCommandWithArgsFromTL() {
-    LatexParser lp = LatexParser::getInstance();
+    QSharedPointer<LatexParser> lp = QSharedPointer<LatexParser>::create();
+    *lp=LatexParser::getInstance();
     LatexPackage pkg_graphics = loadCwlFile("graphicx.cwl");
-    lp.commandDefs.unite(pkg_graphics.commandDescriptions);
+    lp->commandDefs.unite(pkg_graphics.commandDescriptions);
     QFETCH(QString,lines);
     QFETCH(TTypes, types);
     QFETCH(STypes, subtypes);
@@ -463,7 +472,7 @@ void LatexParsingTest::test_getArg_data() {
     QTest::addColumn<QStringList>("desiredResults");
 
 
-    /*QTest::newRow("newcommand command") << "\\newcommand{text}{test}"
+    QTest::newRow("newcommand command") << "\\newcommand{text}{test}"
                                         << (STypes() <<T::def << T::definition)
                                         << (QStringList() <<"text" <<"test");
     QTest::newRow("newcommand command2") << "\\newcommand{\\ext}{test}"
@@ -479,7 +488,7 @@ void LatexParsingTest::test_getArg_data() {
     QTest::newRow("text command, embedded") << "\\textbf{te\\textit{xt} bg}"
                                             << (STypes() <<T::text) << (QStringList() <<"te\\textit{xt} bg");
     QTest::newRow("text command, embedded ,open") << "\\textbf{  te\\textit{xt} bg"
-                                            <<   (STypes() <<T::text) << (QStringList() <<"  te\\textit{xt} bg");*/
+                                            <<   (STypes() <<T::text) << (QStringList() <<"  te\\textit{xt} bg");
     QTest::newRow("text command, multi-line") << "\\textbf{  te\n bg}"
                                             <<   (STypes() <<T::text) << (QStringList() <<"  te bg");
     QTest::newRow("text command, multi-line, with comment") << "\\textbf{  te%abc\n bg}"
@@ -500,9 +509,10 @@ void LatexParsingTest::test_getArg_data() {
 }
 
 void LatexParsingTest::test_getArg() {
-    LatexParser lp = LatexParser::getInstance();
+    QSharedPointer<LatexParser> lp = QSharedPointer<LatexParser>::create();
+    *lp=LatexParser::getInstance();
     LatexPackage pkg_graphics = loadCwlFile("graphicx.cwl");
-    lp.commandDefs.unite(pkg_graphics.commandDescriptions);
+    lp->commandDefs.unite(pkg_graphics.commandDescriptions);
     QFETCH(QString,lines);
     QFETCH(STypes, types);
     QFETCH(QStringList, desiredResults);
@@ -647,9 +657,12 @@ void LatexParsingTest::test_getArg2_data() {
 }
 
 void LatexParsingTest::test_getArg2() {
-    LatexParser lp = LatexParser::getInstance();
+    int storeRUNAWAYLIMIT=ConfigManager::RUNAWAYLIMIT;
+    ConfigManager::RUNAWAYLIMIT=30;
+    QSharedPointer<LatexParser> lp = QSharedPointer<LatexParser>::create();
+    *lp=LatexParser::getInstance();
     LatexPackage pkg_graphics = loadCwlFile("graphicx.cwl");
-    lp.commandDefs.unite(pkg_graphics.commandDescriptions);
+    lp->commandDefs.unite(pkg_graphics.commandDescriptions);
     QFETCH(QString,lines);
     QFETCH(ATypes, types);
     QFETCH(QList<int>, nr);
@@ -679,6 +692,7 @@ void LatexParsingTest::test_getArg2() {
         QCOMPARE(result, desiredResults.at(i));
     }
     delete doc;
+    ConfigManager::RUNAWAYLIMIT=storeRUNAWAYLIMIT;
 }
 
 void LatexParsingTest::test_getTokenAtCol_data() {
@@ -713,9 +727,10 @@ void LatexParsingTest::test_getTokenAtCol_data() {
 }
 
 void LatexParsingTest::test_getTokenAtCol() {
-    LatexParser lp = LatexParser::getInstance();
+    QSharedPointer<LatexParser> lp = QSharedPointer<LatexParser>::create();
+    *lp=LatexParser::getInstance();
     LatexPackage pkg_graphics = loadCwlFile("graphicx.cwl");
-    lp.commandDefs.unite(pkg_graphics.commandDescriptions);
+    lp->commandDefs.unite(pkg_graphics.commandDescriptions);
     QFETCH(QString,lines);
     QFETCH(QList<int>, nr);
     QFETCH(TTypes, desiredResults);
@@ -839,9 +854,10 @@ void LatexParsingTest::test_getCommandFromToken_data() {
 }
 
 void LatexParsingTest::test_getCommandFromToken() {
-    LatexParser lp = LatexParser::getInstance();
+    QSharedPointer<LatexParser> lp = QSharedPointer<LatexParser>::create();
+    *lp=LatexParser::getInstance();
     LatexPackage pkg_graphics = loadCwlFile("graphicx.cwl");
-    lp.commandDefs.unite(pkg_graphics.commandDescriptions);
+    lp->commandDefs.unite(pkg_graphics.commandDescriptions);
     QFETCH(QString,lines);
     QFETCH(int, nr);
     QFETCH(int, lineNr);
@@ -912,9 +928,10 @@ void LatexParsingTest::test_getContext_data() {
 }
 
 void LatexParsingTest::test_getContext() {
-    LatexParser lp = LatexParser::getInstance();
+    QSharedPointer<LatexParser> lp = QSharedPointer<LatexParser>::create();
+    *lp=LatexParser::getInstance();
     LatexPackage pkg_graphics = loadCwlFile("graphicx.cwl");
-    lp.commandDefs.unite(pkg_graphics.commandDescriptions);
+    lp->commandDefs.unite(pkg_graphics.commandDescriptions);
     QFETCH(QString,lines);
     QFETCH(int, nr);
     QFETCH(TTypes, desiredResults);
@@ -948,41 +965,42 @@ void LatexParsingTest::test_getContext() {
 void LatexParsingTest::test_getCompleterContext_data() {
     QTest::addColumn<QString>("lines");
     QTest::addColumn<int >("nr");
-    QTest::addColumn<int >("desiredResult");
+    QTest::addColumn<EnumsTokenType::TokenType >("desiredResult");
 
     QTest::newRow("simple") << "bummerang"
                             << 2
-                            <<  0;
+                            <<  EnumsTokenType::word;
     QTest::newRow("command") << "\\section{abc}"
                             << 10
-                            << 0;
+                            << EnumsTokenType::title;
     QTest::newRow("command without braces") << "\\section abc"
                             << 10
-                            << 0;
+                            << EnumsTokenType::title;
     QTest::newRow("command with optional arg") << "\\section[fds]{abc}"
                             << 10
-                            << 0;
+                            << EnumsTokenType::shorttitle;
     QTest::newRow("command with keyval") << "\\includegraphics[width=4cm]{abc}"
                             << 18
-                            << 0;
+                            << EnumsTokenType::keyVal_key;
     QTest::newRow("command with keyval2") << "\\includegraphics[width=4cm]{abc}"
                             << 24
-                            << 512;
+                            << EnumsTokenType::width;
     QTest::newRow("length") << "\\hspace{4cm}"
                             << 9
-                            << 512;
+                            << EnumsTokenType::width;
 
 
 
 }
 
 void LatexParsingTest::test_getCompleterContext() {
-    LatexParser lp = LatexParser::getInstance();
+    QSharedPointer<LatexParser> lp = QSharedPointer<LatexParser>::create();
+    *lp=LatexParser::getInstance();
     LatexPackage pkg_graphics = loadCwlFile("graphicx.cwl");
-    lp.commandDefs.unite(pkg_graphics.commandDescriptions);
+    lp->commandDefs.unite(pkg_graphics.commandDescriptions);
     QFETCH(QString,lines);
     QFETCH(int, nr);
-    QFETCH(int, desiredResult);
+    QFETCH(EnumsTokenType::TokenType, desiredResult);
 
 
     QDocument *doc = new QDocument();
@@ -1000,7 +1018,7 @@ void LatexParsingTest::test_getCompleterContext() {
     QDocumentLineHandle *dlh = doc->line(0).handle();
     //TokenList tl= dlh->getCookieLocked(QDocumentLine::LEXER_COOKIE).value<TokenList >();
 
-    int result = Parsing::getCompleterContext(dlh, nr);
+    EnumsTokenType::TokenType result = Parsing::getCompleterContext(dlh, nr);
 
     QCOMPARE(result, desiredResult);
 
