@@ -17,6 +17,12 @@ class SyntaxCheckTest: public QObject{
         void checkkeyval();
         void checkArguments_data();
         void checkArguments();
+        void checkMathHighlight_data();
+        void checkMathHighlight();
+        void checkAllowedMath_data();
+        void checkAllowedMath();
+        //void checkIncludes_data();
+        //void checkIncludes();
 };
 
 #endif
