@@ -23,18 +23,21 @@ public:
 	~TexdocDialog();
 
 private slots:
-	void searchTermChanged(const QString &text);
+    void regenerateTable(int state=0);
+    void tableSearchTermChanged(QString term);
+	void itemChanged(QTableWidgetItem* item);
 	void delayedCheckDocAvailable(const QString &package);
 	void checkDockAvailable();
 	void updateDocAvailableInfo(const QString &package, bool available, QString customWarning = QString());
+	void openCtanUrl();
 
 private:
 	Ui::TexdocDialog *ui;
-    QRegularExpressionValidator packageNameValidator;
 	QAbstractButton *openButton;
 	QTimer checkTimer;
 	QString lastDocRequest;
     Help *help;
+    QStringList m_packages;
 };
 
 #endif // TEXDOCDIALOG_H
