@@ -26,7 +26,7 @@
 #include "utilsUI.h"
 
 UserMenuDialog::UserMenuDialog(QWidget *parent,  QString name, QLanguageFactory *languageFactory)
-    : QDialog(parent), languages(languageFactory)
+    : QDialog(parent,Qt::Dialog|Qt::WindowMinMaxButtonsHint|Qt::WindowCloseButtonHint), languages(languageFactory)
 {
 	setWindowTitle(name);
 	ui.setupUi(this);
@@ -58,7 +58,9 @@ UserMenuDialog::UserMenuDialog(QWidget *parent,  QString name, QLanguageFactory
 	ui.tagEdit->setLayout(new QVBoxLayout());
 	codeedit = new QCodeEdit(ui.tagEdit);
 	codeedit->editor()->setFlag(QEditor::AdjustIndent, false);
+	codeedit->editor()->setDisplayModifyTime(false);
 	codeedit->editor()->document()->setCenterDocumentInEditor(false);
+
 	languages->setLanguage(codeedit->editor(), "");
 	//QLineMarkPanel* lineMarkPanel=new QLineMarkPanel;
 	//QAction* lineMarkPanelAction=codeedit->addPanel(lineMarkPanel, QCodeEdit::West, false);
@@ -119,6 +121,7 @@ UserMenuDialog::UserMenuDialog(QWidget *parent,  QString name, QLanguageFactory
 	connect(ui.triggerEdit, SIGNAL(textEdited(QString)), SLOT(triggerChanged()));
 	connect(ui.triggerHelp, SIGNAL(linkActivated(QString)), SLOT(showTooltip()));
 
+    codeedit->editor()->clearFocus();
 }
 
 UserMenuDialog::~UserMenuDialog()
@@ -132,6 +135,9 @@ void UserMenuDialog::addMacro(const Macro &m,bool insertRow)
     auto *item=new QTreeWidgetItem();
     item->setFlags(Qt::ItemIsSelectable | Qt::ItemIsUserCheckable | Qt::ItemIsEnabled | Qt::ItemIsDragEnabled);
     item->setText(0,m.name);
+    item->setText(1,m.shortcut());
+    item->setText(2,m.trigger);
+    item->setText(3,m.abbrev);
     item->setData(0,Qt::UserRole,QVariant::fromValue(m));
     if(insertRow){
         ui.treeWidget->addTopLevelItem(item);
@@ -251,6 +257,15 @@ QTreeWidgetItem *UserMenuDialog::findCreateFolder(QTreeWidgetItem *parent, QStri
     return parent;
 }
 
+void UserMenuDialog::keyPressEvent(QKeyEvent *e)
+{
+    if(e->key()==Qt::Key_Escape && codeedit->editor()->hasFocus()){
+        e->accept();
+        return;
+    }
+    QDialog::keyPressEvent(e);
+}
+
 void UserMenuDialog::change(QTreeWidgetItem *current,QTreeWidgetItem *previous)
 {
     Q_UNUSED(previous)
@@ -274,6 +289,8 @@ void UserMenuDialog::change(QTreeWidgetItem *current,QTreeWidgetItem *previous)
         if (codeedit->editor()->text() != m.typedTag()) {
             codeedit->editor()->setText(m.typedTag(), false);
             setLanguageFromText();
+            codeedit->editor()->setFlag(QEditor::CursorOn,false);
+            codeedit->editor()->repaintCursor();
         }
     }
 }
@@ -406,8 +423,8 @@ void UserMenuDialog::slotMoveDown()
 
 void UserMenuDialog::importMacro()
 {
-    QString fileName = QFileDialog::getOpenFileName(this,tr("Import macro"), "", tr("txs macro files (*.txsMacro)"));
-    if(!fileName.isEmpty()){
+    QStringList fileNames = QFileDialog::getOpenFileNames(this,tr("Import macros"), "", tr("txs macro files (*.txsMacro)"));
+    for(const QString &fileName:fileNames){
         Macro m;
         m.load(fileName);
         addMacro(m,true);
@@ -445,6 +462,8 @@ void UserMenuDialog::changeTypeToNormal()
 	languages->setLanguage(codeedit->editor(), "(La)TeX Macro");
 	if (cur.startsWith("%SCRIPT\n")) codeedit->editor()->setText(cur.mid(8), false);
 	else if (cur.startsWith("%") && !cur.startsWith("%%")) codeedit->editor()->setText(cur.mid(1), false);
+    codeedit->editor()->setFlag(QEditor::CursorOn,false);
+    codeedit->editor()->repaintCursor();
 }
 
 void UserMenuDialog::changeTypeToEnvironment()
@@ -459,6 +478,8 @@ void UserMenuDialog::changeTypeToEnvironment()
 		if (!cur.startsWith("%")) cur = "%" + cur;
 		codeedit->editor()->setText(cur, false);
 	}
+    codeedit->editor()->setFlag(QEditor::CursorOn,false);
+    codeedit->editor()->repaintCursor();
 }
 
 void UserMenuDialog::changeTypeToScript()
@@ -468,6 +489,8 @@ void UserMenuDialog::changeTypeToScript()
 	if (cur.startsWith("%SCRIPT\n")) return;
 	if (cur.startsWith("%") && !cur.startsWith("%%")) cur = cur.mid(1);
 	codeedit->editor()->setText("%SCRIPT\n" + cur, false);
+    codeedit->editor()->setFlag(QEditor::CursorOn,false);
+    codeedit->editor()->repaintCursor();
 }
 
 void UserMenuDialog::textChanged()
@@ -516,6 +539,7 @@ void UserMenuDialog::shortcutChanged()
         Macro m=v.value<Macro>();
         m.setShortcut(ui.cbShortcut->currentText());
         item->setData(0,Qt::UserRole,QVariant::fromValue(m));
+        item->setText(1,m.shortcut());
     }
 }
 
@@ -528,11 +552,27 @@ void UserMenuDialog::abbrevChanged()
         Macro m=v.value<Macro>();
         m.abbrev=ui.abbrevEdit->text();
         item->setData(0,Qt::UserRole,QVariant::fromValue(m));
+        item->setText(3,m.abbrev);
     }
 }
 
 void UserMenuDialog::triggerChanged()
 {
+    // check if trigger is a valid regex
+    const QStringList fixedTriggers{"?txs-start","?new-file","?new-from-template","?load-file","?load-this-file","?save-file","?close-file","?master-changed","?after-typeset","?after-command-run"};
+    const QString text=ui.triggerEdit->text();
+    QRegularExpression re(text);
+    if(!re.isValid() && !fixedTriggers.contains(text)){
+        // syntax error in regex
+        ui.triggerEdit->setToolTip(re.errorString()+tr(" (col. %1)").arg(re.patternErrorOffset()));
+        ui.triggerEdit->setStyleSheet("QLineEdit { background: orange; color : black; }");
+
+        return;
+    }else{
+        ui.triggerEdit->setStyleSheet(QString());
+        ui.triggerEdit->setToolTip("");
+    }
+    // update current macro
     QTreeWidgetItem *item=ui.treeWidget->currentItem();
     if(item==nullptr) return;
     QVariant v=item->data(0,Qt::UserRole);
@@ -540,6 +580,7 @@ void UserMenuDialog::triggerChanged()
         Macro m=v.value<Macro>();
         m.setTrigger(ui.triggerEdit->text());
         item->setData(0,Qt::UserRole,QVariant::fromValue(m));
+        item->setText(2,m.trigger);
     }
 }
 
