@@ -1,6 +1,7 @@
 #include "utilsSystem.h"
 #include "unixutils.h"
 #include "smallUsefulFunctions.h"
+#include <QSvgRenderer>
 
 #ifdef Q_OS_MAC
 #include <CoreFoundation/CFURL.h>
@@ -10,6 +11,7 @@
 #ifdef Q_OS_WIN
 #include <windows.h>
 #endif
+#include <QLibraryInfo>
 bool getDiskFreeSpace(const QString &path, quint64 &freeBytes)
 {
 #ifdef Q_OS_WIN
@@ -21,11 +23,11 @@ bool getDiskFreeSpace(const QString &path, quint64 &freeBytes)
 	freeBytesToCaller.QuadPart = 0L;
 
 	if ( !GetDiskFreeSpaceEx( d, &freeBytesToCaller, NULL, NULL ) ) {
-        delete[] d;
+		delete[] d;
 		qDebug() << "ERROR: Call to GetDiskFreeSpaceEx() failed on path" << path;
 		return false;
 	}
-    delete[] d;
+	delete[] d;
 	freeBytes = freeBytesToCaller.QuadPart;
 	return true;
 #else
@@ -134,13 +136,13 @@ QStringList findResourceFiles(const QString &dirName, const QString &filter, QSt
 	if (!dn.startsWith('/') && !dn.startsWith(QDir::separator())) dn = "/" + dn; //add / at beginning
 	searchFiles << ":" + dn; //resource fall back
 	searchFiles.append(additionalPreferredPaths);
-    searchFiles << QCoreApplication::applicationDirPath() + "/../share/texstudio"; //appimage relative path
+	searchFiles << QCoreApplication::applicationDirPath() + "/../share/texstudio"; //appimage relative path
 	searchFiles << QCoreApplication::applicationDirPath() + dn; //windows new
-    searchFiles << QCoreApplication::applicationDirPath() + "/"; //windows old
-    searchFiles << QCoreApplication::applicationDirPath() + "/dictionaries/"; //windows new
-    searchFiles << QCoreApplication::applicationDirPath() + "/translations/"; //windows new
-    searchFiles << QCoreApplication::applicationDirPath() + "/help/"; //windows new
-    searchFiles << QCoreApplication::applicationDirPath() + "/utilities/"; //windows new
+	searchFiles << QCoreApplication::applicationDirPath() + "/"; //windows old
+	searchFiles << QCoreApplication::applicationDirPath() + "/dictionaries/"; //windows new
+	searchFiles << QCoreApplication::applicationDirPath() + "/translations/"; //windows new
+	searchFiles << QCoreApplication::applicationDirPath() + "/help/"; //windows new
+	searchFiles << QCoreApplication::applicationDirPath() + "/utilities/"; //windows new
 	// searchFiles<<QCoreApplication::applicationDirPath() + "/data/"+fileName; //windows new
 
 #if !defined(PREFIX)
@@ -191,16 +193,24 @@ QString findResourceFile(const QString &fileName, bool allowOverride, QStringLis
 		else searchFiles << s + "/";
 #if defined Q_WS_X11 || defined Q_OS_LINUX || defined Q_OS_UNIX
 	searchFiles << PREFIX"/share/texstudio/"; //X_11
-    searchFiles << QCoreApplication::applicationDirPath() + "/../share/texstudio/"; // relative path for appimage
+	searchFiles << QCoreApplication::applicationDirPath() + "/../share/texstudio/"; // relative path for appimage
 	if (fileName.endsWith(".html")) searchFiles << PREFIX"/share/doc/texstudio/html/"; //for Debian package
+	searchFiles << PREFIX"/share/doc/texstudio/"; //for Debian package
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+	searchFiles << QLibraryInfo::path(QLibraryInfo::TranslationsPath) + "/"; //for systemwise qt_*.qm
+#else
+	searchFiles << QLibraryInfo::location(QLibraryInfo::TranslationsPath) + "/"; //for systemwise qt_*.qm
+#endif
 #endif
 #ifdef Q_OS_MAC
 	searchFiles << QCoreApplication::applicationDirPath() + "/../Resources/"; //macx
+	searchFiles << QCoreApplication::applicationDirPath() + "/../Resources/html/"; //macx
 #endif
 	searchFiles << QCoreApplication::applicationDirPath() + "/"; //windows old
 	searchFiles << QCoreApplication::applicationDirPath() + "/dictionaries/"; //windows new
 	searchFiles << QCoreApplication::applicationDirPath() + "/translations/"; //windows new
 	searchFiles << QCoreApplication::applicationDirPath() + "/help/"; //windows new
+	searchFiles << QCoreApplication::applicationDirPath() + "/help/build/html/"; //windows new manual
 	searchFiles << QCoreApplication::applicationDirPath() + "/utilities/"; //windows new
 	// searchFiles<<QCoreApplication::applicationDirPath() + "/data/"; //windows new
 
@@ -236,12 +246,13 @@ QString findResourceFile(const QString &fileName, bool allowOverride, QStringLis
  */
 QString quoteSpaces(const QString &s)
 {
-    if (!s.contains(' ')) return s;
-    return '"' + s + '"';
+	if (!s.contains(' ')) return s;
+	return '"' + s + '"';
 }
 
 
 int modernStyle;
+int iconTheme;
 bool darkMode;
 bool useSystemTheme;
 
@@ -256,30 +267,38 @@ bool useSystemTheme;
 QString getRealIconFile(const QString &icon)
 {
 	if (icon.isEmpty() || icon.startsWith(":/")) return icon;
-    QStringList suffixList{""};
-    if(darkMode)
-        suffixList=QStringList{"_dm",""};
-    QStringList iconNames = QStringList();
-    for(const QString& suffix : suffixList){
-        iconNames
-                << ":/images-ng/" + icon + suffix + ".svg"
-                << ":/images-ng/" + icon + suffix + ".svgz" ;
-        if (modernStyle) {
-            iconNames << ":/images-ng/modern/" + icon + suffix + ".svg"
-                      << ":/images-ng/modern/" + icon + suffix + ".svgz"
-                      << ":/modern/images/modern/" + icon + suffix + ".png";
-        } else {
-            iconNames << ":/images-ng/classic/" + icon + suffix + ".svg"
-                      << ":/images-ng/classic/" + icon + suffix + ".svgz"
-                      << ":/classic/images/classic/" + icon + suffix + ".png";
-        }
-        iconNames << ":/symbols-ng/icons/" + icon + suffix + ".svg" ;//voruebergehend
-        iconNames << ":/symbols-ng/icons/" + icon + suffix + ".png"; //voruebergehend
-        iconNames << ":/images/" + icon + ".png";
+	QStringList suffixList{""};
+	if(darkMode)
+		suffixList=QStringList{"_dm",""};
+	QStringList iconNames = QStringList();
+	for(const QString& suffix : suffixList){
+
+		QString iconThemeName = "";
+
+		if (iconTheme == 0) { // colibre
+			iconThemeName = "colibre";
+		} else if (iconTheme == 1) { // modern
+			iconThemeName = "modern";
+		} else if (iconTheme == 2) { // classic
+			iconThemeName = "classic";
+		}
+
+		iconNames << ":/images-ng/" + iconThemeName + "/" + icon + suffix + ".svg"
+					<< ":/images-ng/" + iconThemeName + "/" + icon + suffix + ".svgz"
+					<< ":/modern/images/" + iconThemeName + "/" + icon + suffix + ".png";
+
+		iconNames << ":/symbols-ng/icons/" + icon + suffix + ".svg";
+		iconNames << ":/symbols-ng/icons/" + icon + suffix + ".png";
+		iconNames << ":/images/" + icon + ".png";
+
+		// fallback
+		iconNames
+			<< ":/images-ng/" + icon + suffix + ".svg"
+			<< ":/images-ng/" + icon + suffix + ".svgz" ;
     }
 
 	foreach (const QString &name, iconNames) {
-        if (QFileInfo::exists(name))
+		if (QFileInfo::exists(name))
 			return name;
 	}
 
@@ -302,7 +321,7 @@ QIcon getRealIcon(const QString &icon)
 	QString name = getRealIconFile(icon);
 	QIcon ic = QIcon(name);
 	//if(ic.isNull()){
-#if (defined(Q_OS_OSX))
+#if QT_VERSION_MAJOR<6 && defined(Q_OS_OSX)
 	QPixmap pm(32, 32);
 	pm.load(name);
 	ic = QIcon(pm);
@@ -321,7 +340,7 @@ QIcon getRealIcon(const QString &icon)
  */
 QIcon getRealIconCached(const QString &icon, bool forceReload)
 {
-    if (iconCache.contains(icon) && !forceReload) {
+	if (iconCache.contains(icon) && !forceReload) {
 		return *iconCache[icon];
 	}
 	if (icon.isEmpty()) return QIcon();
@@ -343,25 +362,11 @@ QIcon getRealIconCached(const QString &icon, bool forceReload)
 	return *icn;
 }
 
-/*!
- * \brief Tries to determine if the system uses dark mode
- *
- * This function tries to determine if a system uses "dark mode" by looking up general text color and converting it into gray-scale value.
- * A value above 200 (scale is 0 .. 255 ) is considered as light text color on probably dark background, hence a dark mode is detected.
- * This approach is independent on specific on different systems.
- * \return true -> uses dark mode
- */
-bool systemUsesDarkMode(const QPalette &pal)
-{
-    QColor clr=pal.color(QPalette::Text);
-    return qGray(clr.rgb())>200;
-}
-
 bool isFileRealWritable(const QString &filename)
 {
-    if(QFileInfo::exists(filename)){
-        return QFileInfo(filename).isWritable();
-    }
+	if(QFileInfo::exists(filename)){
+		return QFileInfo(filename).isWritable();
+	}
 
 	QFile fi(filename);
 	bool result = false;
@@ -381,7 +386,7 @@ bool isFileRealWritable(const QString &filename)
  */
 bool isExistingFileRealWritable(const QString &filename)
 {
-    return QFileInfo::exists(filename) && isFileRealWritable(filename);
+	return QFileInfo::exists(filename) && isFileRealWritable(filename);
 }
 
 /*!
@@ -674,20 +679,20 @@ void showInGraphicalShell(QWidget *parent, const QString &pathIn)
 	const QString folder = fileInfo.isDir() ? fileInfo.absoluteFilePath() : fileInfo.filePath();
 	QSettings dummySettings;
 	const QString app = UnixUtils::fileBrowser(&dummySettings);
-    QProcess browserProc;
-    const QString browserArg = UnixUtils::substituteFileBrowserParameters(app, folder);
+	QProcess browserProc;
+	const QString browserArg = UnixUtils::substituteFileBrowserParameters(app, folder);
 #if QT_VERSION>=QT_VERSION_CHECK(5,15,0)
-    QStringList args=QProcess::splitCommand(browserArg);
+	QStringList args=QProcess::splitCommand(browserArg);
 #else
-    QStringList args=browserArg.split(" "); // this assumes that the command is not using quotes with spaces in the command path, better solution from qt5.15 ...
+	QStringList args=browserArg.split(" "); // this assumes that the command is not using quotes with spaces in the command path, better solution from qt5.15 ...
 #endif
-    if(args.isEmpty())
-        return;
-    QString cmd=args.takeFirst();
-    for(QString &elem:args){
-        elem=removeQuote(elem);
-    }
-    bool success = browserProc.startDetached(cmd,args);
+	if(args.isEmpty())
+		return;
+	QString cmd=args.takeFirst();
+	for(QString &elem:args){
+		elem=removeQuote(elem);
+	}
+	bool success = browserProc.startDetached(cmd,args);
 	const QString error = QString::fromLocal8Bit(browserProc.readAllStandardError());
 	success = success && error.isEmpty();
 	if (!success)
@@ -792,9 +797,24 @@ void SafeThread::wait(unsigned long time)
 QSet<QString> convertStringListtoSet(const QStringList &list)
 {
 #if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
-    return QSet<QString>(list.begin(),list.end());
+	return QSet<QString>(list.begin(),list.end());
 #else
-    return QSet<QString>::fromList(list);
+	return QSet<QString>::fromList(list);
 #endif
 
 }
+/*!
+ * \brief load Pixmap From SVG directly with given target size
+ * \param fn file name
+ * \param sz target size
+ * \return loaded pixmap
+ */
+QPixmap loadPixmapFromSVG(const QString &fn, const QSize sz)
+{
+    QSvgRenderer svgRender(fn);
+    QImage img(sz, QImage::Format_ARGB32);
+    QPainter p(&img);
+    img.fill(0x000000000);
+    svgRender.render(&p);
+    return QPixmap::fromImage(img);
+}
